@@ -1,11 +1,9 @@
 /* dot1x.h
  * Definitions for IEEE 802.1X
  *
- * $Id: dot1x.h 46 2007-05-08 09:13:30Z slay $ 
- *
  * Yersinia
- * By David Barroso <tomac@yersinia.net> and Alfredo Andres <slay@yersinia.net>
- * Copyright 2005, 2006, 2007 Alfredo Andres and David Barroso
+ * By David Barroso <tomac@yersinia.net> and Alfredo Andres <aandreswork@hotmail.com>
+ * Copyright 2005-2017 Alfredo Andres and David Barroso
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -160,15 +158,15 @@ struct dot1x_mitm_ifaces {
 #define DOT1X_MITM_IFACE_AUTH 1
 
 static struct attack_param dot1x_mitm_params[] = {
-    { NULL, "Supplicant interface",    1, FIELD_IFACE, IFNAMSIZ, NULL },
-    { NULL, "Authenticator interface", 1, FIELD_IFACE, IFNAMSIZ, NULL },
+    { NULL, "Supplicant interface",    1, FIELD_ENABLED_IFACE, IFNAMSIZ, NULL },
+    { NULL, "Authenticator interface", 1, FIELD_ENABLED_IFACE, IFNAMSIZ, NULL },
 };
 
 
 #define DOT1X_ATTACK_SEND 0
 #define DOT1X_ATTACK_MITM 1
 
-static struct attack dot1x_attack[] = {
+static struct _attack_definition dot1x_attack[] = {
     { DOT1X_ATTACK_SEND, "sending 802.1X packet",         NONDOS, SINGLE,    dot1x_th_send, NULL, 0           },
     { DOT1X_ATTACK_MITM, "Mitm 802.1X with 2 interfaces", NONDOS, CONTINOUS, dot1x_th_mitm, dot1x_mitm_params,
               SIZE_ARRAY(dot1x_mitm_params) },
@@ -198,7 +196,7 @@ extern struct interface_data *interfaces_get_packet(list_t *, struct interface_d
 extern int8_t parser_vrfy_mac(char *, u_int8_t *);
 extern int8_t parser_get_inet_aton(char *, struct in_addr *);
 extern int8_t parser_get_formated_inet_address(u_int32_t, char *, u_int16_t);
-extern int8_t parser_command2index(register const struct attack *, register int8_t);
+extern int8_t parser_command2index(register const struct _attack_definition *, register int8_t);
 
 extern struct terminals *terms;
 
