@@ -2,8 +2,8 @@
  * GTK Callbacks
  *
  * Yersinia
- * By David Barroso <tomac@yersinia.net> and Alfredo Andres <slay@yersinia.net>
- * Copyright 2005, 2006, 2007 Alfredo Andres and David Barroso
+ * By David Barroso <tomac@yersinia.net> and Alfredo Andres <aandreswork@hotmail.com>
+ * Copyright 2005-2017 Alfredo Andres and David Barroso
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,14 +20,8 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
-#ifndef lint
-static const char rcsid[] = 
-"$Id: gtk-callbacks.c 48 2007-05-08 09:41:17Z slay $";
-#endif
-
-
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+#include <config.h>
 #endif
 
 #include <time.h>
@@ -141,12 +135,20 @@ gtk_c_savedialog_save(GtkWidget *button, gpointer userdata)
 
 void gtk_c_on_file_quit_activate(GtkMenuItem *menuitem, gpointer user_data)
 {
-   struct gtk_s_helper *helper;
+    struct gtk_s_helper *helper = (struct gtk_s_helper *)user_data;
 
-   helper = (struct gtk_s_helper *)user_data;
-   gtk_statusbar_push(GTK_STATUSBAR(helper->statusbar), 0, "Exiting... be patient");
+    if ( helper->statusbar != NULL )
+        gtk_statusbar_push( GTK_STATUSBAR( helper->statusbar ), 0, "Exiting... be patient" );
    
-   gtk_main_quit();
+    gtk_main_quit();
+}
+
+
+void gtk_c_statusbar_destroy( GtkWidget *widget, gpointer user_data )
+{
+    struct gtk_s_helper *helper = (struct gtk_s_helper *)user_data;
+
+    helper->statusbar = NULL ;
 }
 
 
@@ -156,7 +158,7 @@ on_protocols_proto1_activate           (GtkMenuItem     *menuitem,
 {
 }
 
-
+/* Currently disabled...
 void
 gtk_c_on_protocols_toggle(GtkMenuItem *menuitem, gpointer user_data)
 {
@@ -166,8 +168,7 @@ gtk_c_on_protocols_toggle(GtkMenuItem *menuitem, gpointer user_data)
     n_mode = (u_int8_t *) user_data;
     notebook = lookup_widget(GTK_WIDGET(menuitem), "main_vhv2_notebook");
     n_label = gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook), *n_mode);
-    main_statusbar = lookup_widget(GTK_WIDGET(notebook), "main_statusbar");
-    write_log(0, "joe, voy a hacer algo con %d\n", *n_mode);
+    main_statusbar = lookup_widget(GTK_WIDGET(notebook), "statusbar");
 
     if (gtk_check_menu_item_get_active(GTK_CHECK_MENU_ITEM(menuitem))) {
        gtk_statusbar_push(GTK_STATUSBAR(main_statusbar), 0, "Closing protocol");
@@ -179,7 +180,7 @@ gtk_c_on_protocols_toggle(GtkMenuItem *menuitem, gpointer user_data)
        gtk_widget_show(n_label);
     }
 }
-
+*/
 
 void
 gtk_c_on_actions_execute_activate(GtkMenuItem *menuitem, gpointer user_data)
@@ -209,24 +210,19 @@ gtk_c_on_actions_interfaces_activate (GtkMenuItem *menuitem, gpointer user_data)
 }
 
 
-void
-gtk_c_on_menu_actions_load_default_activate (GtkMenuItem *menuitem, gpointer user_data)
+void gtk_c_on_menu_actions_load_default_activate( GtkMenuItem *menuitem, gpointer user_data )
 {
-    GtkWidget *notebook;
-    struct gtk_s_helper *helper;
-    u_int8_t mode;
+    struct gtk_s_helper *helper = (struct gtk_s_helper *) user_data ;
 
-    helper = (struct gtk_s_helper *) user_data;
-    notebook = lookup_widget(GTK_WIDGET(menuitem), "main_vhv2_notebook");
-    mode = gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook));
+    if ( helper->mode < MAX_PROTOCOLS )
+    {
+        if ( protocols[ helper->mode ].init_attribs )
+           (*protocols[ helper->mode ].init_attribs)( helper->node );
+        else
+           write_log(0, "Warning: no init_attribs for mode %d\n", helper->mode );
 
-    if (protocols[mode].init_attribs)
-       (*protocols[mode].init_attribs)(helper->node);
-    else {
-       write_log(0, "Warning: no init_attribs for mode %d\n", mode);
+        gtk_statusbar_push( GTK_STATUSBAR( helper->statusbar ), 0, "Loaded protocol default values");
     }
-
-    gtk_statusbar_push(GTK_STATUSBAR(helper->statusbar), 0, "Loading protocol default values...");
 }
 
 
@@ -234,15 +230,10 @@ void
 gtk_c_on_menu_actions_list_attacks_activate (GtkMenuItem *menuitem, gpointer user_data)
 {
    GtkWidget *window;
-   GtkWidget *notebook;
-   struct gtk_s_helper *helper;
-   u_int8_t mode;
-
-   helper = (struct gtk_s_helper *)user_data;
-   notebook = lookup_widget(GTK_WIDGET(menuitem), "main_vhv2_notebook");
-   mode = gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook));
+   struct gtk_s_helper *helper = (struct gtk_s_helper *)user_data;
 
    window = gtk_i_create_listattacksdialog(helper->node);
+
    gtk_widget_show(window);
 }
 
@@ -253,7 +244,6 @@ gtk_c_on_actions_clear_activate(GtkMenuItem *menuitem, gpointer user_data)
    struct gtk_s_helper *helper;
    u_int8_t i;
    char buffer[64];
-
    helper = (struct gtk_s_helper *)user_data;
    if (strcmp("ALL", gtk_widget_get_name(GTK_WIDGET(menuitem))) == 0)
        helper->extra = PROTO_ALL;
@@ -268,7 +258,7 @@ gtk_c_on_actions_clear_activate(GtkMenuItem *menuitem, gpointer user_data)
       }
    }
    interfaces_clear_stats(helper->extra);
-   snprintf(buffer, 64, "Clearing stats for mode %s...", gtk_widget_get_name(GTK_WIDGET(menuitem)));
+   snprintf(buffer, 64, "Cleared stats for mode %s", gtk_widget_get_name(GTK_WIDGET(menuitem)));
    gtk_statusbar_push(GTK_STATUSBAR(helper->statusbar), 0, buffer);
 }
 
@@ -304,7 +294,6 @@ gtk_c_capturedialog_save(GtkWidget *button, gpointer userdata)
    GtkWidget *dialog;
    struct gtk_s_helper *helper;
    char *filename;
-   u_int8_t iface;
    pcap_dumper_t *pdumper;
    dlist_t *p;
    struct interface_data *iface_data;
@@ -315,10 +304,8 @@ gtk_c_capturedialog_save(GtkWidget *button, gpointer userdata)
 
    if (helper->extra == PROTO_ALL) {
       pdumper = helper->node->pcap_file.pdumper;
-      iface = interfaces_get_last_int(PROTO_ALL);
    } else {
       pdumper = helper->node->protocol[helper->extra].pcap_file.pdumper;
-      iface = interfaces_get_last_int(helper->extra);
    }
 
    if (pdumper) {
@@ -363,103 +350,192 @@ gtk_c_attacks_synchro(GtkNotebook *attacks_notebook, GtkNotebookPage *page, guin
 }
 
 
-void
-gtk_c_attacks_radio_changed(GtkWidget *radio, gpointer userdata)
+void gtk_c_attacks_radio_changed( GtkWidget *radio, gpointer userdata )
 {
-   u_int8_t i;
-   struct gtk_s_helper *helper;
+    u_int8_t i;
+    struct gtk_s_helper *helper = (struct gtk_s_helper *) userdata;;
 
-   if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(radio))) {
-      helper = (struct gtk_s_helper *) userdata;
-      i = 0;
-      while(protocols[helper->mode].attacks[i].s) {
-         if (strcmp(gtk_button_get_label(GTK_BUTTON(radio)), protocols[helper->mode].attacks[i].s) == 0) {
-            helper->row = i;
-            helper->attack = (struct attack *) &protocols[helper->mode].attacks[i];
-            break;
+    if ( gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON( radio ) ) ) 
+    {
+        if ( helper->mode < MAX_PROTOCOLS )
+        {
+            i = 0;
+
+            while( protocols[ helper->mode ].attack_def_list[i].desc )
+            {
+                if ( strcmp( gtk_button_get_label( GTK_BUTTON( radio ) ), protocols[ helper->mode ].attack_def_list[i].desc ) == 0 )
+                {
+                    helper->attack_def = &protocols[ helper->mode ].attack_def_list[i];
+                    helper->row        = i;
+                    break;
+                }
+                i++;
+            }
+        }
     }
-         i++;
-      }
-   }
 }
 
 
-void
-gtk_c_attacks_launch(GtkWidget *button, gpointer userdata)
+void gtk_c_attacks_launch( GtkWidget *button, gpointer userdata )
 {
-   struct gtk_s_helper *helper;
-   GtkWidget *attacksdialog;
-   GtkWidget *attackparamsdialog;
+    struct gtk_s_helper *helper;
+    GtkWidget *attacksdialog;
+    GtkWidget *attackparamsdialog;
+    GTK_ATTACK_PARAMS_CONTEXT *params_ctx ;
 
-   helper = (struct gtk_s_helper *)userdata;
-   attacksdialog = lookup_widget(GTK_WIDGET(button), "attacksdialog");
+    helper = (struct gtk_s_helper *)userdata;
+    attacksdialog = lookup_widget(GTK_WIDGET(button), "attacksdialog");
 
-   if ((helper->attack) && (helper->attack->nparams)) {
-      if ((helper->attack_param = calloc(1, (sizeof(struct attack_param) * helper->attack->nparams))) == NULL)
-      {
-         thread_error(" ncurses_i_attack_screen attack_param calloc",errno);
-         return;
-      }
+    if ( helper->attack_def && helper->attack_def->nparams )
+    {
+        params_ctx = (GTK_ATTACK_PARAMS_CONTEXT *)malloc( sizeof( GTK_ATTACK_PARAMS_CONTEXT ) );
 
-      memcpy(helper->attack_param, (void *)(helper->attack->param), sizeof(struct attack_param) * helper->attack->nparams);
+        params_ctx->attack_status = -1 ;
 
-      if (attack_init_params(helper->node, helper->attack_param, helper->attack->nparams) < 0) {
-         free(helper->attack_param);
-         return;
-      }
+        params_ctx->helper = helper ;
 
-      attackparamsdialog = gtk_i_create_attackparamsdialog(helper, helper->attack_param, helper->attack->nparams);
-      gtk_widget_show(attackparamsdialog);
+        params_ctx->nparams = helper->attack_def->nparams ;
 
-   } else {
-      if (attack_launch(helper->node, helper->mode, helper->row, NULL, 0) < 0)
-         write_log(0, "Error launching attack %d", helper->row);
-   }
+        params_ctx->vh_entry = (GtkWidget **)calloc( params_ctx->nparams, sizeof( GtkWidget * ) ); 
 
-   gtk_widget_destroy(attacksdialog);
+        params_ctx->params_list = (struct attack_param *)calloc( 1, ( sizeof( struct attack_param ) * params_ctx->nparams ) );
+
+        memcpy( params_ctx->params_list, (void *)(helper->attack_def->param), sizeof( struct attack_param ) * params_ctx->nparams );
+
+        if ( attack_init_params( helper->node, params_ctx->params_list, params_ctx->nparams ) < 0 ) 
+        {
+            free( params_ctx->params_list );
+            free( params_ctx->vh_entry );
+            free( params_ctx );
+            return;
+        }
+
+        attackparamsdialog = gtk_i_create_attackparamsdialog( params_ctx );
+
+        gtk_widget_show( attackparamsdialog );
+    }
+    else
+    {
+        if ( attack_launch( helper->node, helper->mode, helper->row, NULL, 0) < 0 )
+            write_log(0, "Error launching attack %d", helper->row);
+    }
+
+    gtk_widget_destroy( attacksdialog );
 }
 
 
-void
-gtk_c_attackparams_launch(GtkWidget *button, gpointer userdata)
+void gtk_c_attackparams_free( gpointer userdata )
 {
-   GtkWidget *widget, *warning;
-   struct gtk_s_helper *helper;
-   char tmp_name[3], *text;
-   u_int8_t i, field;
+    GTK_ATTACK_PARAMS_CONTEXT *params_ctx = (GTK_ATTACK_PARAMS_CONTEXT *)userdata ;
 
-   helper = (struct gtk_s_helper *) userdata;
+    gtk_widget_destroy( GTK_WIDGET( params_ctx->dialog ) );
 
-   for (i=0; i < helper->attack->nparams; i++) {
-      snprintf(tmp_name, 3, "%02d", i);
-      widget = lookup_widget(GTK_WIDGET(button), tmp_name);
+    if ( params_ctx->attack_status == -1 ) /* Attack error */
+    {
+        attack_free_params( params_ctx->params_list, params_ctx->nparams );
 
-      text = (char *) gtk_entry_get_text(GTK_ENTRY(widget));
-      strncpy(helper->attack_param[i].print, text, helper->attack->param[i].size_print);
-   }
+        free( params_ctx->params_list );
+    }
 
-   if (attack_filter_all_params(helper->attack_param, helper->attack->nparams, &field) < 0) {
-      warning = gtk_i_create_warningdialog("Bad data on field %s!!", helper->attack->param[field].desc);
-      gtk_widget_show(warning);
-   } else {
-      if (attack_launch(helper->node, helper->mode, helper->row, helper->attack_param, helper->attack->nparams) < 0)
-         write_log(0, "Error launching attack %d", helper->row);
-   }
+    free( params_ctx->vh_entry );
+
+    free( params_ctx );
 }
 
 
-void
-gtk_c_listattacks_destroyall(GtkWidget *button, gpointer userdata)
+void gtk_c_attackparams_cancel_click( GtkWidget *button, gpointer userdata )
 {
-   struct term_node *node;
-   GtkWidget *listattacksdialog;
+    gtk_c_attackparams_free( userdata );
+}
 
-   node = (struct term_node *) userdata;
-   listattacksdialog = lookup_widget(GTK_WIDGET(button), "listattacksdialog");
 
-   attack_kill_th(node, ALL_ATTACK_THREADS);
+gboolean gtk_c_attackparams_delete_event( GtkWidget *widget, GdkEvent *event, gpointer userdata )
+{
+    gtk_c_attackparams_free( userdata );
 
-   gtk_widget_destroy(GTK_WIDGET(listattacksdialog));
+    return FALSE ;
+}
+
+
+void gtk_c_attackparams_ok_click( GtkWidget *button, gpointer userdata )
+{
+    GTK_ATTACK_PARAMS_CONTEXT *params_ctx = (GTK_ATTACK_PARAMS_CONTEXT *)userdata ;
+    char *text;
+    u_int8_t i, field;
+
+    for ( i=0; i < params_ctx->nparams; i++ )
+    {
+        text = (char *)gtk_entry_get_text( GTK_ENTRY( params_ctx->vh_entry[i] ) );
+
+        strncpy( params_ctx->params_list[i].print, text, params_ctx->helper->attack_def->param[i].size_print );
+    }
+
+    if ( attack_filter_all_params( params_ctx->params_list, params_ctx->nparams, &field ) < 0 )
+    {
+        if ( params_ctx->helper->attack_def->param[field].type == FIELD_ENABLED_IFACE )
+            gtk_i_modaldialog( GTK_MESSAGE_ERROR, "Attack parameters", "Nonexistant or disabled network interface on field '%s'!!\n\nHave you enabled that interface?",
+                               params_ctx->helper->attack_def->param[field].desc );
+        else
+            gtk_i_modaldialog( GTK_MESSAGE_ERROR, "Attack parameters", "Bad data on field '%s'!!", params_ctx->helper->attack_def->param[field].desc );
+    }
+    else
+    {
+        params_ctx->attack_status = attack_launch( params_ctx->helper->node, params_ctx->helper->mode, params_ctx->helper->row,
+                                                   params_ctx->params_list, params_ctx->nparams );
+
+        if ( params_ctx->attack_status < 0 )
+            write_log(0, "Error launching attack %d", params_ctx->helper->row);
+
+        gtk_c_attackparams_free( userdata );
+    }
+}
+
+
+void gtk_c_listattacks_free( gpointer userdata )
+{
+    GTK_DIALOG_ATTACK_CONTEXT *dialog_ctx = (GTK_DIALOG_ATTACK_CONTEXT *)userdata ;
+
+    gtk_widget_destroy( GTK_WIDGET( dialog_ctx->dialog ) );
+
+    free( dialog_ctx->enabled_attacks_list );
+
+    free( dialog_ctx );
+}
+
+
+void gtk_c_listattacks_stopall_click( GtkWidget *button, gpointer userdata )
+{
+    GTK_DIALOG_ATTACK_CONTEXT *dialog_ctx = (GTK_DIALOG_ATTACK_CONTEXT *)userdata ;
+
+    attack_kill_th( dialog_ctx->node, ALL_ATTACK_THREADS );
+
+    gtk_c_listattacks_free( userdata );
+}
+
+
+void gtk_c_listattacks_stop_click( GtkWidget *button, gpointer userdata )
+{
+    GTK_ATTACK_CONTEXT *gtk_attack_ctx = (GTK_ATTACK_CONTEXT *)userdata ;
+
+    attack_kill_index( gtk_attack_ctx->node, gtk_attack_ctx->protocol, gtk_attack_ctx->attack );
+
+    gtk_button_set_label( GTK_BUTTON( button ), "Stopped" );
+
+    gtk_widget_set_sensitive( gtk_attack_ctx->h_box, FALSE );
+}
+
+
+gboolean gtk_c_listattacks_delete_event( GtkWidget *widget, GdkEvent *event, gpointer userdata )
+{
+    gtk_c_listattacks_free( userdata );
+
+    return FALSE ;
+}
+
+
+void gtk_c_listattacks_quit_click( GtkWidget *button, gpointer userdata )
+{
+    gtk_c_listattacks_free( userdata );
 }
 
 
@@ -474,7 +550,7 @@ gtk_c_update_hexview(GtkTreeSelection *selection, gpointer userdata)
    struct gtk_s_helper *helper;
    u_int8_t row, mode, *packet;
    u_int16_t length, oset;
-   int32_t j, line;
+   int32_t j;
    register u_int i;
    register int s1, s2;
    register int nshorts;
@@ -485,7 +561,6 @@ gtk_c_update_hexview(GtkTreeSelection *selection, gpointer userdata)
    gchar *out;
 
    j = 0;
-   line = 0;
    oset = 0;
    length = 0;
    packet = NULL;
@@ -572,103 +647,97 @@ gtk_c_update_hexview(GtkTreeSelection *selection, gpointer userdata)
    }
 }
 
-
-void
-on_menu_actions_clear_activate  (GtkMenuItem     *menuitem,
-                                 GtkWidget       *notebook)
+void on_menu_actions_clear_activate( GtkMenuItem *menuitem, GtkWidget *notebook )
 {
     GtkWidget *main_statusbar;
     u_int8_t mode;
 
-    mode = gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook));
-    main_statusbar = lookup_widget(GTK_WIDGET(notebook), "main_statusbar");
-    interfaces_clear_stats(mode);
-    gtk_statusbar_push(GTK_STATUSBAR(main_statusbar), 0, "Clearing Mode stats...");
-}
+    mode = gtk_notebook_get_current_page( GTK_NOTEBOOK( notebook ) );
 
+    if ( mode < MAX_PROTOCOLS ) 
+    {
+        main_statusbar = lookup_widget(GTK_WIDGET(notebook), "statusbar");
+        interfaces_clear_stats( mode );
+        gtk_statusbar_push( GTK_STATUSBAR( main_statusbar ), 0, "Mode stats cleared" );
+    }
+}
 
 void gtk_c_on_menu_options_edit_toggle (GtkWidget *menu, gpointer userdata)
 {
-   GtkWidget *notebook, *toolbar_edit, *widget, *warning;
-   struct gtk_s_helper *helper;
-   u_int8_t i, j, mode;
-   struct commands_param *param;
-   char tmp_name[5], *text;
+    GtkWidget *notebook, *widget, *warning;
+    struct gtk_s_helper *helper;
+    u_int8_t i, j;
+    struct commands_param *param;
+    char tmp_name[5], *text;
 
-   helper = (struct gtk_s_helper *)userdata;
+    helper = (struct gtk_s_helper *)userdata;
 
-   notebook = lookup_widget(GTK_WIDGET(menu), "main_vhv2_notebook");
-   toolbar_edit = lookup_widget(GTK_WIDGET(menu), "toolbar_edit");
-   mode = gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook));
-   if (helper->edit_mode) {
-      for(i = 0; i < MAX_PROTOCOLS; i++) {
-         if (protocols[i].visible) {
-            param = (struct commands_param *)protocols[i].parameters;
-            for (j = 0; j < protocols[i].nparams; j++) {
-               if ((param[j].type != FIELD_DEFAULT) && (param[j].type != FIELD_IFACE) && (param[j].type != FIELD_EXTRA)) {
-                  snprintf(tmp_name, 5, "%02d%02d", i, j);
-                  widget = lookup_widget(GTK_WIDGET(notebook), tmp_name);
-                  text = (char *) gtk_entry_get_text(GTK_ENTRY(widget));
-                  if (parser_filter_param(param[j].type, helper->node->protocol[i].commands_param[j],
-                           text, param[j].size_print, param[j].size) < 0) {
-                     warning = gtk_i_create_warningdialog("Bad Parameter %s with wrong value %s in protocol %s!", 
-                           param[j].ldesc, text, protocols[i].namep);
-                     gtk_widget_show(warning);
-                     //break;
-                  }
-                  gtk_entry_set_editable(GTK_ENTRY(widget), FALSE);
-               }
-            }
-         }
-      }
-      helper->edit_mode = 0;
-      gtk_statusbar_push(GTK_STATUSBAR(helper->statusbar), 0, "Edit mode disabled");
-   } else {
-      helper->edit_mode = 1;
-      for (i = 0; i < MAX_PROTOCOLS; i++) {
-         if (protocols[i].visible) {
-            param = (struct commands_param *)protocols[i].parameters;
-            for (j = 0; j < protocols[i].nparams; j++) {
-               if ((param[j].type != FIELD_DEFAULT) && (param[j].type != FIELD_IFACE) && (param[j].type != FIELD_EXTRA)) {
-                  snprintf(tmp_name, 5, "%02d%02d", i, j);
-                  widget = lookup_widget(GTK_WIDGET(notebook), tmp_name);
-                  gtk_entry_set_editable(GTK_ENTRY(widget), TRUE);
-               }
-            }
-         }
-      }
-      gtk_statusbar_push(GTK_STATUSBAR(helper->statusbar), 0, "Edit mode enabled");
-   }
+    if ( helper->mode < MAX_PROTOCOLS )
+    {
+        notebook = lookup_widget(GTK_WIDGET(menu), "main_vhv2_notebook");
+        if (helper->edit_mode) 
+        {
+          for(i = 0; i < MAX_PROTOCOLS; i++) 
+          {
+             if (protocols[i].visible) 
+             {
+                param = (struct commands_param *)protocols[i].parameters;
+                for (j = 0; j < protocols[i].nparams; j++) 
+                {
+                   if ((param[j].type != FIELD_DEFAULT) && (param[j].type != FIELD_IFACE) && (param[j].type != FIELD_EXTRA)) {
+                      snprintf(tmp_name, 5, "%02d%02d", i, j);
+                      widget = lookup_widget(GTK_WIDGET(notebook), tmp_name);
+                      text = (char *) gtk_entry_get_text(GTK_ENTRY(widget));
+                      if (parser_filter_param(param[j].type, helper->node->protocol[i].commands_param[j],
+                               text, param[j].size_print, param[j].size) < 0) {
+                         warning = gtk_i_create_warningdialog("Bad Parameter %s with wrong value %s in protocol %s!", 
+                               param[j].ldesc, text, protocols[i].namep);
+                         gtk_widget_show(warning);
+                         //break;
+                      }
+                      gtk_entry_set_editable(GTK_ENTRY(widget), FALSE);
+                   }
+                }
+             }
+          }
+          helper->edit_mode = 0;
+          gtk_statusbar_push(GTK_STATUSBAR(helper->statusbar), 0, "Edit mode disabled");
+        } 
+        else 
+        {
+          helper->edit_mode = 1;
+          for (i = 0; i < MAX_PROTOCOLS; i++) {
+             if (protocols[i].visible) {
+                param = (struct commands_param *)protocols[i].parameters;
+                for (j = 0; j < protocols[i].nparams; j++) {
+                   if ((param[j].type != FIELD_DEFAULT) && (param[j].type != FIELD_IFACE) && (param[j].type != FIELD_EXTRA)) {
+                      snprintf(tmp_name, 5, "%02d%02d", i, j);
+                      widget = lookup_widget(GTK_WIDGET(notebook), tmp_name);
+                      gtk_entry_set_editable(GTK_ENTRY(widget), TRUE);
+                   }
+                }
+             }
+          }
+          gtk_statusbar_push(GTK_STATUSBAR(helper->statusbar), 0, "Edit mode enabled");
+        }
+    }
 }
 
 
-void on_menu_options_macspoofing_toggle (GtkCheckMenuItem *menu, struct term_node *node)
+void on_menu_options_macspoofing_toggle( GtkCheckMenuItem *menu_item, gpointer user_data )
 {
-   GtkWidget *notebook, *main_statusbar;
-   u_int8_t mode;
+    struct gtk_s_helper *helper = (struct gtk_s_helper *)user_data ;
 
-   notebook = lookup_widget(GTK_WIDGET(menu), "main_vhv2_notebook");
-   mode = gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook));
-   main_statusbar = lookup_widget(GTK_WIDGET(notebook), "main_statusbar");
-   if (node->mac_spoofing) {
-      node->mac_spoofing = 0;
-      gtk_statusbar_push(GTK_STATUSBAR(main_statusbar), 0, "MAC Spoofing set to OFF");
-      gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(menu), FALSE);
-   } else {
-      node->mac_spoofing = 1;
-      gtk_statusbar_push(GTK_STATUSBAR(main_statusbar), 0, "MAC Spoofing set to ON");
-      gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(menu), TRUE);
-   }
-}
-
-
-void
-on_help_about_activate(GtkMenuItem *menuitem, gpointer user_data)
-{
-   GtkWidget *aboutdialog;
-
-   aboutdialog = gtk_i_create_aboutdialog();
-   gtk_widget_show(aboutdialog);
+    if ( helper->node->mac_spoofing ) 
+    {
+        helper->node->mac_spoofing = 0;
+        gtk_statusbar_push( GTK_STATUSBAR( helper->statusbar ), 0, "MAC Spoofing set to OFF" );
+    } 
+    else 
+    {
+        helper->node->mac_spoofing = 1;
+        gtk_statusbar_push( GTK_STATUSBAR( helper->statusbar ), 0, "MAC Spoofing set to ON" );
+    }
 }
 
 
@@ -692,32 +761,39 @@ gtk_c_clock_update(GtkWidget *clock)
 
 
 void
-gtk_c_tree_update(GtkWidget *tree_model)
+gtk_c_tree_update( GtkWidget *tree_model )
 {
-  u_int8_t i, j;
-  GtkTreeIter iter;
-  GtkTreePath *path;
-  char tmp[3];
-  
-  j = 0;
-  for (i=0; i < MAX_PROTOCOLS; i++)
-  {
-    if (protocols[i].visible) {
-      snprintf(tmp, 3, "%d", j);
-      /* Modify a particular row */
-      path = gtk_tree_path_new_from_string (tmp);
-      gtk_tree_model_get_iter (GTK_TREE_MODEL (tree_model), &iter, path);
-      gtk_tree_path_free (path);
-      gtk_list_store_set (GTK_LIST_STORE(tree_model), &iter, 1, protocols[i].packets, -1);
-      j++;
-    }
-  }
+    u_int8_t i, j;
+    GtkTreeIter iter;
+    GtkTreePath *path;
+    char tmp[3];
 
-  snprintf(tmp, 3, "%d", j);
-  path = gtk_tree_path_new_from_string(tmp);
-  gtk_tree_model_get_iter (GTK_TREE_MODEL (tree_model), &iter, path);
-  gtk_tree_path_free (path);
-  gtk_list_store_set (GTK_LIST_STORE(tree_model), &iter, 1, packet_stats.global_counter.total_packets, -1);
+    j = 0;
+    for( i=0; i < MAX_PROTOCOLS; i++ )
+    {
+        if (protocols[i].visible) 
+        {
+          snprintf( tmp, 3, "%d", j );
+          /* Modify a particular row */
+          path = gtk_tree_path_new_from_string( tmp );
+          if ( path )
+          {
+              gtk_tree_model_get_iter( GTK_TREE_MODEL( tree_model ), &iter, path );
+              gtk_list_store_set( GTK_LIST_STORE( tree_model ), &iter, 1, protocols[i].packets, -1 );
+              gtk_tree_path_free( path );
+          }
+          j++;
+        }
+    }
+
+    snprintf( tmp, 3, "%d", j );
+    path = gtk_tree_path_new_from_string( tmp );
+    if ( path )
+    {
+        gtk_tree_model_get_iter( GTK_TREE_MODEL( tree_model ), &iter, path );
+        gtk_list_store_set( GTK_LIST_STORE( tree_model ), &iter, 1, packet_stats.global_counter.total_packets, -1 );
+        gtk_tree_path_free( path );
+    }
 }
 
 
@@ -741,12 +817,11 @@ gtk_c_refresh_mwindow_notebook(GtkNotebook *notebook, GtkNotebookPage *page, gui
 gboolean
 gtk_c_refresh_mwindow(gpointer userdata)
 {
-   u_int8_t i, j, k, val, tlv, mode;
+   u_int8_t i, j, k, val, tlv;
    char *ptrtlv;
    char timebuf[19], meaningbuf[64], **values;
    struct commands_param *params;
    struct commands_param_extra *extra_params;
-   struct tuple_type_desc *func;
    GtkTreeIter iter;
    GtkListStore *tree_model;
    GtkWidget *entry[20];
@@ -759,44 +834,39 @@ gtk_c_refresh_mwindow(gpointer userdata)
    notebook = GTK_NOTEBOOK(helper->notebook);
    tlv = 0;
    values = NULL;
-   func = NULL;
-   mode = 0;
-
-   mode = gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook));
 
    /* Check if it is Yersinia log */
-   if (mode == MAX_PROTOCOLS) {
+   if ( ! helper->mode || ( helper->mode >= MAX_PROTOCOLS ) ) 
       return TRUE;
-   }
 
-   params = protocols[mode].parameters;
-   extra_params = protocols[mode].extra_parameters;
+   params = protocols[helper->mode].parameters;
+   extra_params = protocols[helper->mode].extra_parameters;
 
-   if ((tree_model = GTK_LIST_STORE(gtk_tree_view_get_model(GTK_TREE_VIEW(protocols_tree[mode])))) == NULL)
+   if ((tree_model = GTK_LIST_STORE(gtk_tree_view_get_model(GTK_TREE_VIEW(protocols_tree[helper->mode])))) == NULL)
       write_log(0, "Error in gtk_tree_view_get_model\n");
 
    valid = gtk_tree_model_get_iter_first (GTK_TREE_MODEL(tree_model), &iter);
 
    for (i = 0; i < MAX_PACKET_STATS; i++)
    {
-      if (protocols[mode].stats[i].header->ts.tv_sec > 0) 
+      if (protocols[helper->mode].stats[i].header->ts.tv_sec > 0) 
       {
          /* If there isn't a row, append it */
          if (!valid) {
             gtk_list_store_append (GTK_LIST_STORE (tree_model), &iter);
          }
 
-         if (protocols[mode].get_printable_packet)
+         if (protocols[helper->mode].get_printable_packet)
          {
-            if ((values = (*protocols[mode].get_printable_packet)(&protocols[mode].stats[i])) == NULL) 
+            if ((values = (*protocols[helper->mode].get_printable_packet)(&protocols[helper->mode].stats[i])) == NULL) 
             {
-               write_log(0, "Error in get_printable_packet (mode %d)\n", mode);
+               write_log(0, "Error in get_printable_packet (mode %d)\n", helper->mode);
                return FALSE;
             }
          }
          else
          {
-            write_log(0, "Warning: there is no get_printable_packet for protocol %d\n", mode);
+            write_log(0, "Warning: there is no get_printable_packet for protocol %d\n", helper->mode);
             return FALSE;
          }
 
@@ -806,7 +876,7 @@ gtk_c_refresh_mwindow(gpointer userdata)
          val++;
 
          /* Normal parameters (-2 for the interface and defaults) */
-         while (j < protocols[mode].nparams)
+         while (j < protocols[helper->mode].nparams)
          {
             if (params[j].mwindow)
             {
@@ -824,11 +894,11 @@ gtk_c_refresh_mwindow(gpointer userdata)
 
             j++;
          }
-         if ((protocols[mode].extra_nparams > 0))
+         if ( protocols[helper->mode].extra_nparams > 0 )
          {
             tlv = k;
             j = 0;
-            while(j < protocols[mode].extra_nparams)
+            while(j < protocols[helper->mode].extra_nparams)
             {
                if (extra_params[j].mwindow)
                {
@@ -858,11 +928,11 @@ gtk_c_refresh_mwindow(gpointer userdata)
             }
          }
 
-         gtk_list_store_set (GTK_LIST_STORE(tree_model), &iter, val, protocols[mode].stats[i].iface, -1);
+         gtk_list_store_set (GTK_LIST_STORE(tree_model), &iter, val, protocols[helper->mode].stats[i].iface, -1);
          val++;
-         gtk_list_store_set (GTK_LIST_STORE(tree_model), &iter, val, protocols[mode].stats[i].total, -1);
+         gtk_list_store_set (GTK_LIST_STORE(tree_model), &iter, val, protocols[helper->mode].stats[i].total, -1);
          val++;
-         strftime(timebuf, 19, "%d %b %H:%M:%S", localtime((time_t *)&protocols[mode].stats[i].header->ts));
+         strftime(timebuf, 19, "%d %b %H:%M:%S", localtime((time_t *)&protocols[helper->mode].stats[i].header->ts));
          gtk_list_store_set (GTK_LIST_STORE(tree_model), &iter, val, timebuf, -1);
 
          k = 0;
@@ -885,13 +955,13 @@ gtk_c_refresh_mwindow(gpointer userdata)
 
    /* Ok, now refresh the bwindow */
    if (!helper->edit_mode) {
-      for (i = 0; i < protocols[mode].nparams; i++)
+      for (i = 0; i < protocols[helper->mode].nparams; i++)
       {
          if ((params[i].type != FIELD_DEFAULT) && (params[i].type != FIELD_IFACE) && (params[i].type != FIELD_EXTRA))
          {
-            snprintf(tmp_name, 5, "%02d%02d", mode, i);
+            snprintf(tmp_name, 5, "%02d%02d", helper->mode, i);
             entry[i] = lookup_widget(GTK_WIDGET(notebook), tmp_name);
-            parser_binary2printable(mode, i, helper->node->protocol[mode].commands_param[i], msg);
+            parser_binary2printable( helper->mode, i, helper->node->protocol[helper->mode].commands_param[i], msg );
             gtk_entry_set_text(GTK_ENTRY(entry[i]), msg);
          }
       }
@@ -909,15 +979,13 @@ gtk_c_tree_selection_changed_cb (GtkTreeSelection *selection, gpointer userdata)
    GtkWidget *tree;
    GtkListStore *tree_model;
    u_int8_t row;
-   u_int8_t i, j, line, k, mode;
+   u_int8_t j, k, mode;
    char **values, *ptrtlv;
    struct commands_param *params;
-   struct tuple_type_desc *func;
    struct gtk_s_helper *helper;
 
    helper = (struct gtk_s_helper *) userdata;
    values = NULL;
-   func = NULL;
    row = 0;
 
    if (gtk_tree_selection_get_selected (selection, &model, &iter))
@@ -927,13 +995,11 @@ gtk_c_tree_selection_changed_cb (GtkTreeSelection *selection, gpointer userdata)
       row = 0;
    }
 
-   i = 0;
-   line = 0;
    mode = gtk_notebook_get_current_page(GTK_NOTEBOOK(helper->notebook));
    params = (struct commands_param *)protocols[mode].parameters;
 
    if (protocols[mode].stats[row].header->ts.tv_sec <= 0) {
-      write_log(0, "Ohhh no hay paquetes del modo %d, fila %d :(\n", mode, row);
+      /* write_log(0, "Ohhh no hay paquetes del modo %d, fila %d :(\n", mode, row); */
       return;
    }
 
@@ -964,7 +1030,7 @@ gtk_c_tree_selection_changed_cb (GtkTreeSelection *selection, gpointer userdata)
          gtk_list_store_set(GTK_LIST_STORE(tree_model), &iter, 0, params[j].ldesc, -1);
          gtk_list_store_set(GTK_LIST_STORE(tree_model), &iter, 1, values[k], -1);
          if (params[j].meaning)
-            gtk_list_store_set (GTK_LIST_STORE(tree_model), &iter, 2, parser_get_meaning(values[k], params[j].meaning));
+            gtk_list_store_set( GTK_LIST_STORE( tree_model ), &iter, 2, parser_get_meaning( values[k], params[j].meaning ), -1 );
          k++;
       }
       j++;
@@ -1014,65 +1080,57 @@ gtk_c_tree_selection_changed_cb (GtkTreeSelection *selection, gpointer userdata)
 void
 gtk_c_toggle_interface(GtkWidget *toggle, struct term_node *node)
 {
-   gboolean state;
-   const gchar *label;
-   dlist_t *found;
-   struct interface_data *iface_data, *iface_new;
+    gboolean state;
+    const gchar *label;
+    dlist_t *found;
+    struct interface_data *iface_data, *iface_new;
 
-   label = gtk_button_get_label(GTK_BUTTON(toggle));
+    label = gtk_button_get_label(GTK_BUTTON(toggle));
 
+    state = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(toggle));
+    if (!state)
+    {
+        found = dlist_search(node->used_ints->list, node->used_ints->cmp, (void *)label);
+        iface_data = (struct interface_data *) dlist_data(found);
+        interfaces_disable(iface_data->ifname);
+        node->used_ints->list = dlist_remove(node->used_ints->list, (void *)iface_data);
+    }
+    else
+    {
+        /* First we need to get the interface index */
+        found = dlist_search(interfaces->list, interfaces->cmp, (void *)label);
 
-   state = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(toggle));
-   if (!state) {
-      found = dlist_search(node->used_ints->list, node->used_ints->cmp, (void *)label);
-      iface_data = (struct interface_data *) dlist_data(found);
-      interfaces_disable(iface_data->ifname);
-      node->used_ints->list = dlist_remove(node->used_ints->list, (void *)iface_data);
-   } else {
-      /* First we need to get the interface index */
-      found = dlist_search(interfaces->list, interfaces->cmp, (void *)label);
+        if ( !found )
+            return;
 
-      if (!found) /* Not found */
-         return;
+        iface_data = (struct interface_data *) dlist_data(found);
 
-      iface_data = (struct interface_data *) dlist_data(found);
-
-      interfaces_enable(iface_data->ifname);
-      iface_new = (struct interface_data *) calloc(1, sizeof(struct interface_data));
-      memcpy((void *)iface_new, (void *)iface_data, sizeof(struct interface_data));
-      node->used_ints->list = dlist_append(node->used_ints->list, (void *)iface_new);
-   }
+        interfaces_enable(iface_data->ifname);
+        iface_new = (struct interface_data *)malloc( sizeof(struct interface_data) );
+        if ( iface_new )
+        {
+            memcpy((void *)iface_new, (void *)iface_data, sizeof(struct interface_data));
+            node->used_ints->list = dlist_append(node->used_ints->list, (void *)iface_new);
+        }
+    }
 }
 
-/*
-gboolean
-gtk_c_view_onPopupMenu(GtkWidget *treeview, gpointer userdata)
-{
-    view_popup_menu(treeview, NULL, userdata);
-
-    return TRUE;
-}*/
-
 
 void
 gtk_c_view_popup_menu(GtkWidget *menuitem, gpointer userdata)
 {
-    struct gtk_s_helper *helper;
-    u_int8_t mode, row;
-    struct term_node *node;
+    struct gtk_s_helper *helper = (struct gtk_s_helper *)userdata;
 
-    helper = (struct gtk_s_helper *)userdata;
-
-    node = (struct term_node *) helper->node;
-    mode = helper->mode;
-    row = helper->row;
-
-    //write_log(0, "Cargando de mode es %d y row es %d\n", mode, row);
-    if (protocols[mode].load_values)
-        (*protocols[mode].load_values)((struct pcap_data *)&protocols[mode].stats[row], node->protocol[mode].tmp_data);
-    else {
-        write_log(0, "Warning: no load_values in protocol %d\n", mode);
+    if ( protocols[ helper->mode ].load_values )
+    {
+        if ( ( helper->row >= 0 ) && ( helper->row < MAX_PACKET_STATS ) && ( protocols[ helper->mode ].stats[ helper->row ].packet ) )
+            (*protocols[ helper->mode ].load_values)( (struct pcap_data *)&protocols[ helper->mode ].stats[ helper->row ],
+                                                      helper->node->protocol[ helper->mode ].tmp_data );
+        else
+            write_log(0, "WARNING: gtk_c_view_popup_menu: Mode[%d] Invalid row [%d] or NULL packet pointer!!\n", helper->mode, helper->row );
     }
+    else
+         write_log(0, "WARNING: gtk_c_view_popup_menu: No load_values callback for protocol %d\n", helper->mode);
 }
 
 
@@ -1086,7 +1144,6 @@ gtk_c_view_onButtonPressed (GtkWidget *treeview, GdkEventButton *event, gpointer
     gint *index;
     u_int8_t mode;
 
-
     index = NULL;
     notebook = lookup_widget(GTK_WIDGET(treeview), "main_vhv2_notebook");
     wmain = lookup_widget(GTK_WIDGET(treeview), "Main");
@@ -1097,24 +1154,27 @@ gtk_c_view_onButtonPressed (GtkWidget *treeview, GdkEventButton *event, gpointer
     if (event->type == GDK_BUTTON_PRESS  &&  event->button == 3)
     {
       selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(treeview));
-
-     if (gtk_tree_selection_count_selected_rows(selection)  <= 1)
-     {
-           /* Get tree path for row that was clicked */
-           if (gtk_tree_view_get_path_at_pos(GTK_TREE_VIEW(treeview),
-                                             (gint) event->x, 
-                                             (gint) event->y,
-                                             &path, NULL, NULL, NULL))
-           {
-             index = gtk_tree_path_get_indices(path);
-             gtk_tree_selection_unselect_all(selection);
-             gtk_tree_selection_select_path(selection, path);
-             gtk_tree_path_free(path);
-           }
+      
+      if (gtk_tree_selection_count_selected_rows(selection)  <= 1)
+      {
+         /* Get tree path for row that was clicked */
+         if (gtk_tree_view_get_path_at_pos(GTK_TREE_VIEW(treeview),
+                                           (gint) event->x, 
+                                           (gint) event->y,
+                                           &path, NULL, NULL, NULL))
+         {
+           index = gtk_tree_path_get_indices(path);
+           gtk_tree_selection_unselect_all(selection);
+           gtk_tree_selection_select_path(selection, path);
+           gtk_tree_path_free(path);
+         }
       }
 
      helper->mode = mode;
-     helper->row = *index;
+
+     if ( index != NULL )
+         helper->row = *index;
+
      gtk_i_view_menu(treeview, wmain, event, helper);
 
       return TRUE; /* we handled this */
@@ -1132,8 +1192,8 @@ gtk_c_on_extra_button_clicked(GtkButton *button, gpointer userdata)
 
    helper = (struct gtk_s_helper *)userdata;
 
-   //write_log(0, "helper es %d\n", helper->mode);
    extrawindow = gtk_i_create_extradialog(helper);
+
    gtk_widget_show(extrawindow);
 }
 
@@ -1147,7 +1207,6 @@ gtk_c_extra_button_add_clicked(GtkButton *button, gpointer userdata)
 
    helper = (struct gtk_s_helper *)userdata;
 
-   //write_log(0, "helper es %X\n", helper);
    proto = gtk_notebook_get_current_page(GTK_NOTEBOOK(helper->notebook));
    window = gtk_i_create_add_extradialog(helper, proto);
    gtk_widget_show(window);
@@ -1157,8 +1216,6 @@ gtk_c_extra_button_add_clicked(GtkButton *button, gpointer userdata)
 void
 gtk_c_add_extra_button_add_ok_clicked(GtkButton *button, gpointer userdata)
 {
-   struct gtk_s_helper *helper;
-
-   helper = (struct gtk_s_helper *)userdata;
+    /* Do nothing */
 }
-/* vim:set tabstop=3:set expandtab:set shiftwidth=3:set textwidth=78: */
+/* vim:set tabstop=4:set expandtab:set shiftwidth=4:set textwidth=120: */
