@@ -1,11 +1,9 @@
 /* gtk_callbacks.h
  * Definitions GTK callbacks
  *
- * $Id: gtk-callbacks.h 43 2007-04-27 11:07:17Z slay $ 
- *
  * Yersinia
- * By David Barroso <tomac@yersinia.net> and Alfredo Andres <slay@yersinia.net>
- * Copyright 2005, 2006, 2007 Alfredo Andres and David Barroso
+ * By David Barroso <tomac@yersinia.net> and Alfredo Andres <aandreswork@hotmail.com>
+ * Copyright 2005-2017 Alfredo Andres and David Barroso
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -49,23 +47,25 @@ void gtk_c_on_file_quit_activate(GtkMenuItem *, gpointer);
 void
 on_protocols_proto1_activate           (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
+/* Disabled...
 void gtk_c_on_protocols_toggle(GtkMenuItem *, gpointer);
+*/
 void gtk_c_on_actions_execute_activate(GtkMenuItem *, gpointer);
 void gtk_c_on_actions_interfaces_activate(GtkMenuItem *, gpointer);
 void gtk_c_on_menu_actions_load_default_activate (GtkMenuItem *menuitem, gpointer);
 void gtk_c_on_menu_actions_list_attacks_activate (GtkMenuItem *menuitem, gpointer);
 void on_menu_actions_clear_activate (GtkMenuItem *, GtkWidget *);
 void gtk_c_on_menu_options_edit_toggle (GtkWidget *, gpointer);
-void on_menu_options_macspoofing_toggle (GtkCheckMenuItem *, struct term_node *);
-void on_help_about_activate(GtkMenuItem *menuitem, gpointer user_data);
+void on_menu_options_macspoofing_toggle (GtkCheckMenuItem *, gpointer);
 void gtk_c_on_actions_clear_activate(GtkMenuItem *, gpointer);
 void gtk_c_on_capture_activate(GtkMenuItem *, gpointer);
 void gtk_c_capturedialog_save(GtkWidget *, gpointer);
 void gtk_c_attacks_synchro(GtkNotebook *, GtkNotebookPage *, guint,  gpointer);
 void gtk_c_attacks_radio_changed(GtkWidget *, gpointer);
 void gtk_c_attacks_launch(GtkWidget *, gpointer);
-void gtk_c_attackparams_launch(GtkWidget *, gpointer);
-void gtk_c_listattacks_destroyall(GtkWidget *, gpointer);
+void gtk_c_attackparams_cancel_click( GtkWidget *, gpointer );
+void gtk_c_attackparams_ok_click( GtkWidget *, gpointer );
+gboolean gtk_c_attackparams_delete_event( GtkWidget *, GdkEvent *, gpointer );
 void gtk_c_update_hexview(GtkTreeSelection *, gpointer);
 void gtk_c_clock_update(GtkWidget *);
 void gtk_c_tree_update(GtkWidget *);
@@ -79,9 +79,14 @@ gboolean gtk_c_view_onButtonPressed (GtkWidget *treeview, GdkEventButton *event,
 void gtk_c_on_extra_button_clicked(GtkButton *, gpointer);
 void gtk_c_extra_button_add_clicked(GtkButton *, gpointer);
 void gtk_c_add_extra_button_add_ok_clicked(GtkButton *, gpointer);
+void gtk_c_statusbar_destroy( GtkWidget *, gpointer );
+gboolean gtk_c_listattacks_delete_event( GtkWidget *, GdkEvent *, gpointer );
+void gtk_c_listattacks_quit_click( GtkWidget *, gpointer );
+void gtk_c_listattacks_stopall_click( GtkWidget *, gpointer );
+void gtk_c_listattacks_stop_click( GtkWidget *, gpointer );
 
 /* External functions */
 extern void write_log( u_int16_t mode, char *msg, ... );
 
 #endif
-/* vim:set tabstop=4:set expandtab:set shiftwidth=4:set textwidth=78: */
+/* vim:set tabstop=4:set expandtab:set shiftwidth=4:set textwidth=120: */
