@@ -3,8 +3,8 @@
  * GTK Interface setup
  *
  * Yersinia
- * By David Barroso <tomac@yersinia.net> and Alfredo Andres <slay@yersinia.net>
- * Copyright 2005, 2006, 2007 Alfredo Andres and David Barroso
+ * By David Barroso <tomac@yersinia.net> and Alfredo Andres <aandreswork@hotmail.com>
+ * Copyright 2005-2017 Alfredo Andres and David Barroso
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -21,16 +21,10 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
-#ifndef lint
-static const char rcsid[] = 
-"$Id: gtk-interface.c 43 2007-04-27 11:07:17Z slay $";
-#endif
-
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+#include <config.h>
 #endif
 
-
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <unistd.h>
@@ -86,7 +80,6 @@ gtk_i_create_Main (struct gtk_s_helper *helper)
    GtkWidget *menu_capture_proto1;
    GtkWidget *menu_options;
    GtkWidget *menu_options_menu;
-   GtkWidget *menu_options_edit;
    GtkWidget *menu_options_macspoofing;
    GtkWidget *menu_help;
    GtkWidget *menu_help_menu;
@@ -135,7 +128,6 @@ gtk_i_create_Main (struct gtk_s_helper *helper)
    GtkWidget *main_log;
    GtkTooltips *tooltips;
    GtkAccelGroup *accel_group;
-   GdkColor color;
    PangoFontDescription *font_desc;
 
    accel_group = gtk_accel_group_new ();
@@ -151,6 +143,8 @@ gtk_i_create_Main (struct gtk_s_helper *helper)
    gtk_window_set_title (GTK_WINDOW (Main), title);
    gtk_window_set_default_size (GTK_WINDOW (Main), 640, 480);
 
+    g_signal_connect( Main, "delete_event", G_CALLBACK( gtk_c_on_file_quit_activate ), helper );
+
    main_vbox = gtk_vbox_new (FALSE, 0);
    gtk_widget_show (main_vbox);
    gtk_container_add (GTK_CONTAINER (Main), main_vbox);
@@ -206,9 +200,9 @@ gtk_i_create_Main (struct gtk_s_helper *helper)
       if (protocols[i].visible)
          gtk_widget_show (menu_protocols_proto1);
       gtk_container_add (GTK_CONTAINER (menu_protocols_menu), menu_protocols_proto1);
-      g_signal_connect ((gpointer) menu_protocols_proto1, "toggle",
-            G_CALLBACK (gtk_c_on_protocols_toggle),
-            &i);
+      /* Disabled, wrong usage!! Variable 'i' on stack!!
+      g_signal_connect ((gpointer) menu_protocols_proto1, "toggled", G_CALLBACK (gtk_c_on_protocols_toggle), &i);
+      */
    }
 
    /* Menu Actions */
@@ -337,19 +331,6 @@ gtk_i_create_Main (struct gtk_s_helper *helper)
    menu_options_menu = gtk_menu_new ();
    gtk_menu_item_set_submenu (GTK_MENU_ITEM (menu_options), menu_options_menu);
 
-   /* Menu Options - Edit mode */
-   /*menu_options_edit = gtk_check_menu_item_new_with_mnemonic (_("_Edit mode"));
-     if (helper->edit_mode)
-     gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(menu_options_edit), TRUE);
-     else
-     gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM(menu_options_edit), FALSE);
-
-     gtk_widget_show (menu_options_edit);
-     gtk_container_add (GTK_CONTAINER (menu_options_menu), menu_options_edit);
-     gtk_widget_add_accelerator (menu_options_edit, "activate", accel_group,
-     GDK_E, (GdkModifierType) GDK_CONTROL_MASK,
-     GTK_ACCEL_VISIBLE);*/
-
    /* Menu Options - MAC Spoofing */
    menu_options_macspoofing = gtk_check_menu_item_new_with_mnemonic (_("_MAC Spoofing"));
    if (helper->node->mac_spoofing)
@@ -528,9 +509,9 @@ gtk_i_create_Main (struct gtk_s_helper *helper)
 
    main_vhvv_eventbox = gtk_event_box_new();
    gtk_widget_set_size_request (main_vhvv_eventbox, 20, 20);
-   color.red = 0;
-   color.green = 0;
-   color.blue = 0;
+   //color.red = 0;
+   //color.green = 0;
+   //color.blue = 0;
    //gtk_widget_modify_bg (GTK_WIDGET(main_vhvv_eventbox), GTK_STATE_NORMAL, &color);
    gtk_container_set_border_width(GTK_CONTAINER(main_vhvv_eventbox), 1);
    gtk_widget_show(main_vhvv_eventbox);
@@ -606,6 +587,9 @@ gtk_i_create_Main (struct gtk_s_helper *helper)
 
    /* Status bar - botton of the screen */
    helper->statusbar = gtk_statusbar_new ();
+
+   g_signal_connect( (gpointer)helper->statusbar, "destroy", G_CALLBACK( gtk_c_statusbar_destroy ), (gpointer)helper );
+
    gtk_widget_show (helper->statusbar);
 
    gtk_box_pack_start (GTK_BOX (main_vbox), helper->statusbar, FALSE, FALSE, 0);
@@ -645,15 +629,13 @@ gtk_i_create_Main (struct gtk_s_helper *helper)
    g_signal_connect ((gpointer) menu_actions_clear, "activate",
          G_CALLBACK (on_menu_actions_clear_activate),
          main_vhv2_notebook);
-   /*  g_signal_connect ((gpointer) menu_options_edit, "toggle",
-       G_CALLBACK (gtk_c_on_menu_options_edit_toggle),
-       helper);*/
-   g_signal_connect ((gpointer) menu_options_macspoofing, "toggle",
-         G_CALLBACK (on_menu_options_macspoofing_toggle),
-         helper->node);
-   g_signal_connect ((gpointer) menu_help_about, "activate",
-         G_CALLBACK (on_help_about_activate),
-         NULL);
+
+   g_signal_connect( (gpointer) menu_options_macspoofing, "toggled",
+                      G_CALLBACK( on_menu_options_macspoofing_toggle ),
+                      helper );
+   g_signal_connect( (gpointer) menu_help_about, "activate",
+                      G_CALLBACK( gtk_i_create_aboutdialog ),
+                      NULL );
 
    /* Toolbar signals */
    g_signal_connect ((gpointer) toolbar_launch, "clicked",
@@ -708,7 +690,6 @@ gtk_i_create_Main (struct gtk_s_helper *helper)
    GLADE_HOOKUP_OBJECT (Main, menu_capture_menu, "menu_capture_menu");
    GLADE_HOOKUP_OBJECT (Main, menu_options, "menu_options");
    GLADE_HOOKUP_OBJECT (Main, menu_options_menu, "menu_options_menu");
-   GLADE_HOOKUP_OBJECT (Main, menu_options_edit, "menu_options_edit");
    GLADE_HOOKUP_OBJECT (Main, menu_options_macspoofing, "menu_options_macspoofing");
    GLADE_HOOKUP_OBJECT (Main, menu_help, "menu_help");
    GLADE_HOOKUP_OBJECT (Main, menu_help_menu, "menu_help_menu");
@@ -890,182 +871,188 @@ gtk_i_create_capturedialog (struct gtk_s_helper *helper)
 }
 
 
-GtkWidget*
-gtk_i_create_aboutdialog (void)
+void gtk_i_create_aboutdialog( GtkMenuItem *menuitem, gpointer user_data )
+
 {
-   GtkWidget *aboutdialog;
-   int j;
-   const gchar *authors[] = {
+    GtkWidget *aboutdialog;
+    int j;
+    const gchar *authors[] = {
       "David Barroso Berrueta <tomac@yersinia.net>",
-      "Alfredo Andr\303\251s Omella <slay@yersinia.net>",
+      "Alfredo Andr\303\251s Omella <aandreswork@hotmail.com>",
       NULL
-   };
-   /* TRANSLATORS: Replace this string with your names, one name per line. */
-   gchar *translators = _("translator-credits");
-   GdkPixbuf *aboutdialog_logo_pixbuf;
+    };
+    gchar *translators = _("translator-credits");
+    GdkPixbuf *aboutdialog_logo_pixbuf;
 
-   aboutdialog = gtk_about_dialog_new ();
-   gtk_about_dialog_set_version (GTK_ABOUT_DIALOG (aboutdialog), VERSION);
-   gtk_about_dialog_set_name (GTK_ABOUT_DIALOG (aboutdialog), _("Yersinia"));
-   gtk_about_dialog_set_copyright (GTK_ABOUT_DIALOG (aboutdialog), _(" Yersinia\n By David Barroso <tomac@yersinia.net> and Alfredo Andres <slay@yersinia.net>\nCopyright 2005, 2006, 2007 Alfredo Andres and David Barroso"));
-   j = term_motd();
-   if (j >= 0)
-      gtk_about_dialog_set_comments (GTK_ABOUT_DIALOG (aboutdialog), _(vty_motd[j]));
+    aboutdialog = gtk_about_dialog_new();
 
-   gtk_about_dialog_set_license (GTK_ABOUT_DIALOG (aboutdialog), LICENSE); 
-   gtk_about_dialog_set_website (GTK_ABOUT_DIALOG (aboutdialog), "http://www.yersinia.net");
-   gtk_about_dialog_set_website_label (GTK_ABOUT_DIALOG (aboutdialog), _("http://daslfkjsdf"));
-   gtk_about_dialog_set_authors (GTK_ABOUT_DIALOG (aboutdialog), authors);
-   gtk_about_dialog_set_translator_credits (GTK_ABOUT_DIALOG (aboutdialog), translators);
-   aboutdialog_logo_pixbuf = create_pixbuf ("yersinia.png");
-   gtk_about_dialog_set_logo (GTK_ABOUT_DIALOG (aboutdialog), aboutdialog_logo_pixbuf);
+    gtk_about_dialog_set_version( GTK_ABOUT_DIALOG( aboutdialog ), VERSION );
+    gtk_about_dialog_set_name( GTK_ABOUT_DIALOG( aboutdialog ), _( "Yersinia" ) );
+    gtk_about_dialog_set_copyright( GTK_ABOUT_DIALOG( aboutdialog ), _( " Yersinia\n By David Barroso <tomac@yersinia.net> and Alfredo Andres <aandreswork@hotmail.com>\nCopyright 2005-2017 Alfredo Andres and David Barroso" ) );
 
-   /* Store pointers to all widgets, for use by lookup_widget(). */
-   GLADE_HOOKUP_OBJECT_NO_REF (aboutdialog, aboutdialog, "aboutdialog");
+    j = term_motd();
 
-   return aboutdialog;
+    if (j >= 0)
+      gtk_about_dialog_set_comments( GTK_ABOUT_DIALOG( aboutdialog ), _( vty_motd[j] ) );
+
+    gtk_about_dialog_set_license( GTK_ABOUT_DIALOG( aboutdialog ), LICENSE ); 
+    gtk_about_dialog_set_website( GTK_ABOUT_DIALOG( aboutdialog ), "http://www.yersinia.net");
+    gtk_about_dialog_set_website_label( GTK_ABOUT_DIALOG( aboutdialog), _("http://www.yersinia.net"));
+    gtk_about_dialog_set_authors( GTK_ABOUT_DIALOG( aboutdialog ), authors );
+    gtk_about_dialog_set_translator_credits( GTK_ABOUT_DIALOG( aboutdialog ), translators );
+
+    aboutdialog_logo_pixbuf = create_pixbuf( "yersinia.png" );
+    
+    gtk_about_dialog_set_logo( GTK_ABOUT_DIALOG( aboutdialog ), aboutdialog_logo_pixbuf );
+
+    gtk_dialog_run( GTK_DIALOG( aboutdialog ) );
+
+    gtk_widget_destroy( aboutdialog );
 }
 
 
-GtkWidget*
-gtk_i_create_attacksdialog (GtkWidget *notebook, struct gtk_s_helper *helper, u_int8_t mode)
+GtkWidget *gtk_i_create_attacksdialog( GtkWidget *notebook, struct gtk_s_helper *helper, u_int8_t mode )
 {
-   GtkWidget *attacksdialog;
-   GtkWidget *attacks_frame;
-   GtkWidget *attacks_vbox;
-   GtkWidget *attacks_v_table;
-   GtkWidget *attacks_notebook;
-   GtkWidget *attacks_n_labels[MAX_PROTOCOLS];
-   GtkWidget *attacks_vt_radio_attack[MAX_PROTOCOLS];
-   GtkWidget *attacks_vt_label_attack;
-   GtkWidget *attacks_vt_label_dos;
-   GtkWidget *attacks_vt_check_attack1;
-   GtkWidget *attacks_v_hbox;
-   GtkWidget *attacks_vh_cancel_button;
-   GtkWidget *attacks_vh_ok_button;
-   struct attack *theattack = NULL;
-   u_int8_t i, j, num_attacks;
+    GtkWidget *main_dialog;
+    GtkWidget *attacks_frame;
+    GtkWidget *attacks_vbox;
+    GtkWidget *attacks_v_table = NULL ;
+    GtkWidget *attacks_notebook;
+    GtkWidget *attacks_n_labels[MAX_PROTOCOLS];
+    GtkWidget *attacks_vt_radio_attack[MAX_PROTOCOLS];
+    GtkWidget *attacks_vt_label_attack = NULL ;
+    GtkWidget *attacks_vt_label_dos = NULL ;
+    GtkWidget *attacks_vt_check_attack1 = NULL ;
+    GtkWidget *attacks_v_hbox;
+    GtkWidget *attacks_vh_cancel_button;
+    GtkWidget *attacks_vh_ok_button;
+    struct _attack_definition *attack_def ;
+    u_int8_t i, j, num_attacks;
 
-   attacksdialog = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-   gtk_window_set_title (GTK_WINDOW (attacksdialog), _("Choose attack"));
-   gtk_window_set_position (GTK_WINDOW (attacksdialog), GTK_WIN_POS_CENTER_ON_PARENT);
+    helper->attack_def = NULL ;
+    helper->row        = 0 ;
 
-   attacks_vbox = gtk_vbox_new (FALSE, 0);
-   gtk_widget_show (attacks_vbox);
-   gtk_container_add (GTK_CONTAINER (attacksdialog), attacks_vbox);
+    main_dialog = gtk_window_new( GTK_WINDOW_TOPLEVEL );
+    gtk_window_set_title( GTK_WINDOW( main_dialog ), _( "Choose protocol attack" ) );
+    gtk_window_set_position( GTK_WINDOW( main_dialog ), GTK_WIN_POS_CENTER_ON_PARENT );
+    gtk_window_set_resizable( GTK_WINDOW( main_dialog ), FALSE );
 
-   attacks_notebook = gtk_notebook_new ();
-   gtk_widget_show(attacks_notebook);
+    attacks_vbox = gtk_vbox_new (FALSE, 0);
+    gtk_widget_show (attacks_vbox);
+    gtk_container_add( GTK_CONTAINER( main_dialog ), attacks_vbox );
 
-   g_signal_connect_after(G_OBJECT(attacks_notebook), "switch-page",
-         G_CALLBACK(gtk_c_attacks_synchro), (gpointer)notebook);
+    attacks_notebook = gtk_notebook_new ();
+    gtk_widget_show(attacks_notebook);
 
-   gtk_box_pack_start (GTK_BOX (attacks_vbox), attacks_notebook, TRUE, TRUE, 0);
+    g_signal_connect_after( G_OBJECT(attacks_notebook), "switch-page", G_CALLBACK( gtk_c_attacks_synchro ), (gpointer)notebook );
 
-   for (i=0; i < MAX_PROTOCOLS; i++)
-   {   
-      if (protocols[i].attacks) {
-         theattack = (struct attack *)protocols[i].attacks;
+    gtk_box_pack_start( GTK_BOX( attacks_vbox ), attacks_notebook, TRUE, TRUE, 0 );
 
-         attacks_frame = gtk_frame_new(_("Choose attack"));
-         if (protocols[i].visible)
-            gtk_widget_show(attacks_frame);
-         gtk_container_add (GTK_CONTAINER (attacks_notebook), attacks_frame);
+    for (i=0; i < MAX_PROTOCOLS; i++)
+    {   
+      if ( protocols[i].attack_def_list ) 
+      {
+         attack_def = protocols[i].attack_def_list;
 
+         attacks_frame = gtk_frame_new( " Choose attack ");
+         gtk_container_add( GTK_CONTAINER( attacks_notebook ), attacks_frame );
+         if ( protocols[i].visible )
+            gtk_widget_show( attacks_frame );
+    
          attacks_n_labels[i] = gtk_label_new (_(protocols[i].namep));
 
          if (protocols[i].visible)
             gtk_widget_show (attacks_n_labels[i]);
-
+    
          gtk_notebook_set_tab_label (GTK_NOTEBOOK (attacks_notebook), gtk_notebook_get_nth_page (GTK_NOTEBOOK (attacks_notebook), i), attacks_n_labels[i]);
-
-         attacks_v_table = gtk_table_new (SIZE_ARRAY(theattack), 3, FALSE);
+    
+         attacks_v_table = gtk_table_new (SIZE_ARRAY(attack_def), 3, FALSE);
          gtk_widget_show (attacks_v_table);
          gtk_container_add(GTK_CONTAINER(attacks_frame), attacks_v_table);
          gtk_container_set_border_width (GTK_CONTAINER (attacks_v_table), 10);
-
+    
          attacks_vt_label_attack = gtk_label_new (_("Description"));
          gtk_widget_show (attacks_vt_label_attack);
          gtk_table_attach (GTK_TABLE (attacks_v_table), attacks_vt_label_attack, 0, 1, 0, 1,
                (GtkAttachOptions) (GTK_FILL),
                (GtkAttachOptions) (0), 0, 0);
          gtk_misc_set_alignment (GTK_MISC (attacks_vt_label_attack), 0, 0.5);
-
+    
          attacks_vt_label_dos = gtk_label_new (_("DoS"));
          gtk_widget_show (attacks_vt_label_dos);
          gtk_table_attach (GTK_TABLE (attacks_v_table), attacks_vt_label_dos, 1, 2, 0, 1,
                (GtkAttachOptions) (GTK_FILL),
                (GtkAttachOptions) (0), 0, 0);
          gtk_misc_set_alignment (GTK_MISC (attacks_vt_label_dos), 0, 0.5);
-
+    
          num_attacks = 0;
-         while(theattack[num_attacks].s)
+    
+         while ( attack_def[num_attacks].desc )
             num_attacks++;
-
-         for(j = 0; j < num_attacks; j++) {
+    
+         for(j = 0; j < num_attacks; j++) 
+         {
             if (j == 0)
-               attacks_vt_radio_attack[i] = gtk_radio_button_new_with_label(NULL, theattack[j].s);
+               attacks_vt_radio_attack[i] = gtk_radio_button_new_with_label( NULL, attack_def[j].desc );
             else
-               attacks_vt_radio_attack[i] = gtk_radio_button_new_with_label_from_widget(GTK_RADIO_BUTTON(attacks_vt_radio_attack[i]), (theattack[j].s));
+               attacks_vt_radio_attack[i] = gtk_radio_button_new_with_label_from_widget( GTK_RADIO_BUTTON( attacks_vt_radio_attack[i] ), ( attack_def[j].desc ) );
+    
             gtk_widget_show (attacks_vt_radio_attack[i]);
-
+    
             g_signal_connect(attacks_vt_radio_attack[i], "toggled", (GCallback) gtk_c_attacks_radio_changed, helper);
-
+    
             gtk_table_attach (GTK_TABLE (attacks_v_table), attacks_vt_radio_attack[i], 0, 1, j+1, j+2,
                   (GtkAttachOptions) (GTK_FILL),
                   (GtkAttachOptions) (0), 0, 0);
-
+    
             attacks_vt_check_attack1 = gtk_check_button_new();
             gtk_widget_set_sensitive(GTK_WIDGET(attacks_vt_check_attack1), FALSE);
-            if (theattack[j].type == DOS)
+    
+            if ( attack_def[j].type == DOS )
                gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(attacks_vt_check_attack1), TRUE);
             else
                gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(attacks_vt_check_attack1), FALSE);
-
+    
             gtk_widget_show (attacks_vt_check_attack1);
             gtk_table_attach (GTK_TABLE (attacks_v_table), attacks_vt_check_attack1, 1, 2, j+1, j+2,
                   (GtkAttachOptions) (GTK_FILL),
                   (GtkAttachOptions) (0), 0, 0);
          }
       }
-   }
+    }
 
-   /* Start in the same label than the main window */
-   gtk_notebook_set_current_page(GTK_NOTEBOOK(attacks_notebook), mode);
+    /* Start in the same label than the main window */
+    gtk_notebook_set_current_page( GTK_NOTEBOOK( attacks_notebook ), mode );
+    
+    attacks_v_hbox = gtk_hbox_new( TRUE, 0 );
+    gtk_widget_show(attacks_v_hbox);
+    gtk_container_add( GTK_CONTAINER( attacks_vbox ), attacks_v_hbox );
 
-   attacks_v_hbox = gtk_hbox_new (TRUE, 0);
-   gtk_widget_show (attacks_v_hbox);
-   gtk_container_add (GTK_CONTAINER (attacks_vbox), attacks_v_hbox);
+    attacks_vh_cancel_button = gtk_button_new_with_mnemonic (_("Cancel"));
+    gtk_widget_show (attacks_vh_cancel_button);
+    gtk_box_pack_start (GTK_BOX (attacks_v_hbox), attacks_vh_cancel_button, FALSE, TRUE, 0);
+    
+    g_signal_connect_swapped((gpointer) attacks_vh_cancel_button, "clicked", G_CALLBACK( gtk_widget_destroy ), GTK_OBJECT( main_dialog ) );
 
-   attacks_vh_cancel_button = gtk_button_new_with_mnemonic (_("Cancel"));
-   gtk_widget_show (attacks_vh_cancel_button);
-   gtk_box_pack_start (GTK_BOX (attacks_v_hbox), attacks_vh_cancel_button, FALSE, TRUE, 0);
+    attacks_vh_ok_button = gtk_button_new_with_mnemonic (_("OK"));
+    gtk_widget_show (attacks_vh_ok_button);
+    gtk_box_pack_start( GTK_BOX( attacks_v_hbox ), attacks_vh_ok_button, FALSE, TRUE, 0 );
 
-   g_signal_connect_swapped ((gpointer) attacks_vh_cancel_button, "clicked",
-         G_CALLBACK (gtk_widget_destroy),
-         GTK_OBJECT (attacksdialog));
+    g_signal_connect((gpointer) attacks_vh_ok_button, "clicked", G_CALLBACK( gtk_c_attacks_launch ), helper );
 
-   attacks_vh_ok_button = gtk_button_new_with_mnemonic (_("OK"));
-   gtk_widget_show (attacks_vh_ok_button);
-   gtk_box_pack_start (GTK_BOX (attacks_v_hbox), attacks_vh_ok_button, FALSE, TRUE, 0);
+    /* Store pointers to all widgets, for use by lookup_widget(). */
+    GLADE_HOOKUP_OBJECT_NO_REF( main_dialog, main_dialog, "attacksdialog");
+    GLADE_HOOKUP_OBJECT( main_dialog, attacks_vbox, "attacks_vbox");
+    GLADE_HOOKUP_OBJECT( main_dialog, attacks_v_table, "attacks_v_table");
+    GLADE_HOOKUP_OBJECT( main_dialog, attacks_vt_label_attack, "attacks_vt_label_attack");
+    GLADE_HOOKUP_OBJECT( main_dialog, attacks_vt_label_dos, "attacks_vt_label_dos");
+    GLADE_HOOKUP_OBJECT( main_dialog, attacks_vt_check_attack1, "attacks_vt_check_attack1");
+    GLADE_HOOKUP_OBJECT( main_dialog, attacks_v_hbox, "attacks_v_hbox");
+    GLADE_HOOKUP_OBJECT( main_dialog, attacks_notebook, "attacks_notebook");
+    GLADE_HOOKUP_OBJECT( main_dialog, attacks_vh_cancel_button, "attacks_vh_cancel_button");
+    GLADE_HOOKUP_OBJECT( main_dialog, attacks_vh_ok_button, "attacks_vh_ok_button");
 
-   g_signal_connect((gpointer) attacks_vh_ok_button, "clicked",
-         G_CALLBACK (gtk_c_attacks_launch),
-         helper);
-
-   /* Store pointers to all widgets, for use by lookup_widget(). */
-   GLADE_HOOKUP_OBJECT_NO_REF (attacksdialog, attacksdialog, "attacksdialog");
-   GLADE_HOOKUP_OBJECT (attacksdialog, attacks_vbox, "attacks_vbox");
-   GLADE_HOOKUP_OBJECT (attacksdialog, attacks_v_table, "attacks_v_table");
-   GLADE_HOOKUP_OBJECT (attacksdialog, attacks_vt_label_attack, "attacks_vt_label_attack");
-   GLADE_HOOKUP_OBJECT (attacksdialog, attacks_vt_label_dos, "attacks_vt_label_dos");
-   GLADE_HOOKUP_OBJECT (attacksdialog, attacks_vt_check_attack1, "attacks_vt_check_attack1");
-   GLADE_HOOKUP_OBJECT (attacksdialog, attacks_v_hbox, "attacks_v_hbox");
-   GLADE_HOOKUP_OBJECT (attacksdialog, attacks_notebook, "attacks_notebook");
-   GLADE_HOOKUP_OBJECT (attacksdialog, attacks_vh_cancel_button, "attacks_vh_cancel_button");
-   GLADE_HOOKUP_OBJECT (attacksdialog, attacks_vh_ok_button, "attacks_vh_ok_button");
-
-   return attacksdialog;
+    return main_dialog;
 }
 
 
@@ -1136,91 +1123,158 @@ create_interfacesdialog (struct term_node *node)
 }
 
 
-GtkWidget*
-gtk_i_create_listattacksdialog (struct term_node *node)
+GtkWidget *gtk_i_create_listattacksdialog( struct term_node *node )
 {
-   GtkWidget *listattacksdialog;
-   GtkWidget *listattacks_frame;
-   GtkWidget *listattacks_vbox;
-   GtkWidget *listattacks_v_hbox;
-   GtkWidget *listattacks_vh_label;
-   GtkWidget *listattacks_vh_labeln;
-   GtkWidget *listattacks_vh_labeld;
-   GtkWidget *listattacks_vh_button;
-   GtkWidget *listattacks_v_cancel_button;
-   GtkWidget *listattacks_v_ok_button;
-   struct attack *theattack = NULL;
-   u_int8_t i, j;
+    GtkWidget *main_dialog ;
+    GtkWidget *frame ;
+    GtkWidget *frame_vbox ;
+    GtkWidget *main_vbox ;
+    GtkWidget *attack_hbox ;
+    GtkWidget *stop_button ;
+    GtkWidget *quit_hbox ;
+    GtkWidget *stopall_button ;
+    GtkWidget *quit_button ;
+    GtkWidget *label ;
+    struct _attack_definition *attack_def ;
+    u_int8_t i, j;
+    int attack_count = 0 ;
+    GTK_DIALOG_ATTACK_CONTEXT *dialog_ctx;
+    GTK_ATTACK_CONTEXT *attack_ctx ;
 
-   listattacksdialog = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-   gtk_window_set_title (GTK_WINDOW (listattacksdialog), _("Attacks list"));
-   gtk_window_set_position (GTK_WINDOW (listattacksdialog), GTK_WIN_POS_CENTER_ON_PARENT);
+    dialog_ctx = (GTK_DIALOG_ATTACK_CONTEXT *)calloc( 1, sizeof( GTK_DIALOG_ATTACK_CONTEXT ) );
+    dialog_ctx->enabled_attacks_list = (GTK_ATTACK_CONTEXT *)malloc( sizeof( GTK_ATTACK_CONTEXT ) * MAX_PROTOCOLS * MAX_THREAD_ATTACK );
 
-   listattacks_frame = gtk_frame_new(_("Attacks list"));
-   gtk_widget_show(listattacks_frame);
-   gtk_container_add(GTK_CONTAINER (listattacksdialog), listattacks_frame);
+    attack_ctx = dialog_ctx->enabled_attacks_list ;
 
-   listattacks_vbox = gtk_vbox_new (FALSE, 0);
-   gtk_widget_show (listattacks_vbox);
-   gtk_container_add (GTK_CONTAINER (listattacks_frame), listattacks_vbox);
+    main_dialog = gtk_window_new( GTK_WINDOW_TOPLEVEL );
 
-   for (i = 0; i < MAX_PROTOCOLS; i++)
-   {
-      theattack = protocols[i].attacks;
-      for (j = 0; j < MAX_THREAD_ATTACK; j++)
-      {
-         if (node->protocol[i].attacks[j].up)
-         {
-            listattacks_v_hbox = gtk_hbox_new(FALSE, 0);
-            gtk_widget_show(listattacks_v_hbox);
+    gtk_window_set_title( GTK_WINDOW( main_dialog ), _( "Running Attacks" ) );
+    gtk_window_set_position( GTK_WINDOW( main_dialog ), GTK_WIN_POS_CENTER_ON_PARENT );
+    gtk_window_set_resizable( GTK_WINDOW( main_dialog ), FALSE );
 
-            listattacks_vh_label = gtk_label_new(protocols[i].namep);
-            gtk_widget_show(listattacks_vh_label);
-            gtk_box_pack_start(GTK_BOX(listattacks_v_hbox), listattacks_vh_label, TRUE, TRUE, 0);
-            /*
-               listattacks_vh_labeln = gtk_new_label(node->protocols[i].attacks[j].attack);
-               gtk_widget_show(listattacks_vh_labeln):
-               gtk_box_pack_start(GTK_BOX(listattacks_v_hbox), listattacks_vh_labeln, TRUE, TRUE, 0);
-               */
-            listattacks_vh_labeld = gtk_label_new(theattack[node->protocol[i].attacks[j].attack].s);
-            gtk_widget_show(listattacks_vh_labeld);
-            gtk_box_pack_start(GTK_BOX(listattacks_v_hbox), listattacks_vh_labeld, TRUE, TRUE, 0);
+    dialog_ctx->dialog = main_dialog ;
+    dialog_ctx->node   = node ;
 
-            listattacks_vh_button = gtk_button_new_with_label("Cancel attack");
-            gtk_widget_show(listattacks_vh_button);
-            gtk_box_pack_start(GTK_BOX(listattacks_v_hbox), listattacks_vh_button, TRUE, TRUE, 0);
+    g_signal_connect( main_dialog, "delete_event", G_CALLBACK( gtk_c_listattacks_delete_event ), (gpointer)dialog_ctx );
 
-            gtk_box_pack_start(GTK_BOX (listattacks_vbox), listattacks_v_hbox, TRUE, TRUE, 0);
-         }
-      }
-   }
+    frame      = gtk_frame_new( NULL );
+    frame_vbox = gtk_vbox_new( FALSE, 0 );
+    main_vbox  = gtk_vbox_new( FALSE, 0 );
 
-   listattacks_v_cancel_button = gtk_button_new_with_mnemonic (_("Cancel all attacks"));
-   gtk_widget_show (listattacks_v_cancel_button);
-   gtk_box_pack_start (GTK_BOX (listattacks_vbox), listattacks_v_cancel_button, FALSE, FALSE, 0);
+    gtk_box_pack_start( GTK_BOX( main_vbox ), frame, FALSE, FALSE, 0 );
 
-   g_signal_connect ((gpointer) listattacks_v_cancel_button, "clicked",
-         G_CALLBACK (gtk_c_listattacks_destroyall),
-         node);
+    /* Attacks list... */
+    for( i = 0; i < MAX_PROTOCOLS; i++ )
+    {
+        attack_def = protocols[i].attack_def_list;
 
-   listattacks_v_ok_button = gtk_button_new_with_mnemonic (_("Cancel"));
-   gtk_widget_show (listattacks_v_ok_button);
-   gtk_box_pack_start (GTK_BOX (listattacks_vbox), listattacks_v_ok_button, FALSE, FALSE, 0);
+        for( j = 0; j < MAX_THREAD_ATTACK; j++ )
+        {
+            if ( node->protocol[i].attacks[j].up )
+            {
+                attack_hbox = gtk_hbox_new( FALSE, 5 );
 
-   g_signal_connect_swapped ((gpointer) listattacks_v_ok_button, "clicked",
-         G_CALLBACK (gtk_widget_destroy),
-         GTK_OBJECT (listattacksdialog));
+                /* Attack Proto */
+                label = gtk_label_new( protocols[i].namep );
+                gtk_widget_show( label );
+                gtk_box_pack_start( GTK_BOX( attack_hbox ), label, FALSE, FALSE, 5 );
 
-   /* Store pointers to all widgets, for use by lookup_widget(). */
-   GLADE_HOOKUP_OBJECT_NO_REF (listattacksdialog, listattacksdialog, "listattacksdialog");
-   GLADE_HOOKUP_OBJECT (listattacksdialog, listattacks_vbox, "listattacks_vbox");
-   GLADE_HOOKUP_OBJECT (listattacksdialog, listattacks_v_ok_button, "listattacks_v_ok_button");
-   GLADE_HOOKUP_OBJECT (listattacksdialog, listattacks_v_cancel_button, "listattacks_v_cancel_button");
+                /* Attack Description... */
+                label = gtk_label_new( attack_def[ node->protocol[ i ].attacks[ j ].attack ].desc );
+                gtk_widget_show( label );
+                gtk_box_pack_start( GTK_BOX( attack_hbox ), label, FALSE, FALSE, 0 );
 
-   return listattacksdialog;
+                /* Attack stop button... */
+                stop_button = gtk_button_new_with_label( "   Stop   " );
+                gtk_widget_show( stop_button );
+                gtk_box_pack_end( GTK_BOX( attack_hbox ), stop_button, FALSE, FALSE, 5 );
+
+                attack_ctx->protocol = i ;
+                attack_ctx->attack   = j ;
+                attack_ctx->dialog   = main_dialog ;
+                attack_ctx->node     = node ;
+                attack_ctx->h_box    = attack_hbox ;
+
+                g_signal_connect( (gpointer)stop_button, "clicked", G_CALLBACK( gtk_c_listattacks_stop_click ), (gpointer)attack_ctx );
+
+                attack_ctx++;
+
+                gtk_box_pack_start( GTK_BOX( frame_vbox ), attack_hbox, FALSE, FALSE, 3 );
+                gtk_widget_show( attack_hbox );
+
+                attack_count++;
+            }
+        }
+    }
+
+    /* Bottom buttons... */
+    quit_hbox = gtk_hbox_new( FALSE, 0 );
+
+    if ( attack_count )
+    {
+        stopall_button = gtk_button_new_with_label( " Stop ALL " );
+        g_signal_connect( (gpointer)stopall_button, "clicked", G_CALLBACK( gtk_c_listattacks_stopall_click ), (gpointer)dialog_ctx );
+        gtk_box_pack_start( GTK_BOX( quit_hbox ), stopall_button, TRUE, FALSE, 0 );
+        gtk_widget_show( stopall_button );
+    }
+    else
+    {
+        label = gtk_label_new( " No attacks currently running " );
+        gtk_widget_show( label );
+        gtk_box_pack_start( GTK_BOX( frame_vbox ), label, FALSE, FALSE, 10 );
+    }
+
+    quit_button = gtk_button_new_with_label( "   Quit   " );
+    g_signal_connect( (gpointer)quit_button, "clicked", G_CALLBACK( gtk_c_listattacks_quit_click ), (gpointer)dialog_ctx );
+    gtk_box_pack_start( GTK_BOX( quit_hbox ), quit_button, TRUE, FALSE, 0 );
+
+    gtk_box_pack_start( GTK_BOX( main_vbox ), quit_hbox, FALSE, FALSE, 5 );
+
+    gtk_widget_show( quit_button );
+    gtk_widget_show( quit_hbox );
+
+    gtk_widget_show( frame_vbox );
+    gtk_widget_show( frame );
+    gtk_widget_show( main_vbox );
+
+    gtk_container_add( GTK_CONTAINER( frame ), frame_vbox );
+    gtk_container_add( GTK_CONTAINER( main_dialog ), main_vbox );
+
+    return main_dialog ;
 }
 
 
+void gtk_i_modaldialog( int gtk_msg_type, char *header, char *msg, ...)
+{
+    GtkWidget *dialog ;
+    va_list ap ;
+    char *buffer = (char *)malloc( 2048 );
+
+    if ( buffer )
+    {
+        va_start( ap, msg );
+        vsnprintf( buffer, 2048, msg, ap );
+        va_end( ap );
+
+        if ( header )
+            dialog = gtk_message_dialog_new( NULL, GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+                                             gtk_msg_type, GTK_BUTTONS_OK,
+                                             "%s", header );
+        else
+            dialog = gtk_message_dialog_new( NULL, GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+                                             gtk_msg_type, GTK_BUTTONS_OK,
+                                             NULL );
+
+        gtk_message_dialog_format_secondary_text( GTK_MESSAGE_DIALOG( dialog ), "%s", buffer );
+
+        gtk_dialog_run( GTK_DIALOG( dialog ) );
+
+        gtk_widget_destroy( dialog );
+
+        free( buffer );
+    }
+}
+
 GtkWidget*
 gtk_i_create_warningdialog (char *msg, ...)
 {
@@ -1426,86 +1480,84 @@ gtk_i_create_add_extradialog (struct gtk_s_helper *helper, u_int8_t proto)
 }
 
 
-GtkWidget*
-gtk_i_create_attackparamsdialog (struct gtk_s_helper *helper, struct attack_param *param, u_int8_t nparams)
+GtkWidget *gtk_i_create_attackparamsdialog( GTK_ATTACK_PARAMS_CONTEXT *params_ctx )
 {
-   GtkWidget *attackparamsdialog;
-   GtkWidget *attackparams_frame;
-   GtkWidget *attackparams_vbox;
-   GtkWidget *attackparams_v_hbox;
-   GtkWidget *attackparams_vh_label;
-   GtkWidget **attackparams_vh_entry;
-   GtkWidget *attackparams_vh_button;
-   GtkWidget *attackparams_v_cancel_button;
-   GtkWidget *attackparams_v_ok_button;
-   u_int8_t i;
-   char tmp_name[3];
+    GtkWidget *main_dialog ;
+    GtkWidget *main_vbox ;
+    GtkWidget *frame;
+    GtkWidget *frame_vbox;
+    GtkWidget *param_hbox;
+    GtkWidget *label;
+    GtkWidget *button_hbox ;
+    GtkWidget *cancel_button;
+    GtkWidget *ok_button;
+    u_int8_t i;
+    gchar *title_text = g_strconcat( protocols[ params_ctx->helper->mode ].namep, " attack parameters", NULL );
+    gchar *frame_text = g_strconcat( " ", protocols[ params_ctx->helper->mode ].attack_def_list[ params_ctx->helper->row ].desc, " ", NULL );
 
-   if ((attackparams_vh_entry = (GtkWidget **) calloc(nparams, sizeof(GtkWidget *))) == NULL) {
-      write_log(0, "Error in calloc\n");
-      return NULL;
-   }
+    main_dialog = gtk_window_new( GTK_WINDOW_TOPLEVEL );
 
-   attackparamsdialog = gtk_window_new(GTK_WINDOW_TOPLEVEL);
-   gtk_window_set_title (GTK_WINDOW (attackparamsdialog), _("Parameters list"));
-   gtk_window_set_position (GTK_WINDOW (attackparamsdialog), GTK_WIN_POS_CENTER_ON_PARENT);
+    gtk_window_set_title( GTK_WINDOW( main_dialog ), _( title_text ) );
+    g_free( title_text );
 
-   attackparams_frame = gtk_frame_new(_("Parameters list"));
-   gtk_widget_show(attackparams_frame);
-   gtk_container_add(GTK_CONTAINER (attackparamsdialog), attackparams_frame);
+    gtk_window_set_position( GTK_WINDOW( main_dialog ), GTK_WIN_POS_CENTER_ON_PARENT );
+    gtk_window_set_resizable( GTK_WINDOW( main_dialog ), FALSE );
 
-   attackparams_vbox = gtk_vbox_new (FALSE, 0);
-   gtk_widget_show (attackparams_vbox);
-   gtk_container_add (GTK_CONTAINER (attackparams_frame), attackparams_vbox);
+    params_ctx->dialog = main_dialog ;
 
-   for (i = 0; i < nparams; i++)
-   {
-      attackparams_v_hbox = gtk_hbox_new(FALSE, 0);
-      gtk_widget_show(attackparams_v_hbox);
-      attackparams_vh_label = gtk_label_new(_(param[i].desc));
-      gtk_widget_show(attackparams_vh_label);
-      attackparams_vh_entry[i] = gtk_entry_new();
-      gtk_entry_set_editable(GTK_ENTRY(attackparams_vh_entry[i]), TRUE);
-      gtk_entry_set_width_chars(GTK_ENTRY(attackparams_vh_entry[i]), param[i].size_print);
-      gtk_entry_set_max_length(GTK_ENTRY(attackparams_vh_entry[i]), param[i].size_print);
-      gtk_widget_show(attackparams_vh_entry[i]);
+    main_vbox = gtk_vbox_new( FALSE, 0 );
+    gtk_container_add( GTK_CONTAINER( main_dialog ), main_vbox );
 
-      gtk_box_pack_start(GTK_BOX(attackparams_v_hbox), attackparams_vh_label, TRUE, TRUE, 0);
-      gtk_box_pack_start(GTK_BOX(attackparams_v_hbox), attackparams_vh_entry[i], TRUE, TRUE, 0);
-      gtk_box_pack_start(GTK_BOX (attackparams_vbox), attackparams_v_hbox, TRUE, TRUE, 0);
+    frame = gtk_frame_new( _( frame_text ) );
+    g_free( frame_text );
+    gtk_box_pack_start( GTK_BOX( main_vbox ), frame, FALSE, FALSE, 0 );
 
-      snprintf(tmp_name, 3, "%02d", i);
-      GLADE_HOOKUP_OBJECT (attackparamsdialog, attackparams_vh_entry[i], tmp_name);
-   }
+    frame_vbox = gtk_vbox_new( FALSE, 0 );
+    gtk_container_add( GTK_CONTAINER( frame ), frame_vbox );
 
-   attackparams_vh_button = gtk_hbox_new(TRUE, 0);
-   gtk_widget_show(attackparams_vh_button);
-   gtk_container_add (GTK_CONTAINER (attackparams_vbox), attackparams_vh_button);
+    for (i = 0; i < params_ctx->nparams; i++)
+    {
+        param_hbox = gtk_hbox_new( FALSE, 5 );
 
-   attackparams_v_cancel_button = gtk_button_new_with_mnemonic (_("Cancel"));
-   gtk_widget_show (attackparams_v_cancel_button);
-   gtk_box_pack_start (GTK_BOX (attackparams_vh_button), attackparams_v_cancel_button, TRUE, FALSE, 0);
+        label = gtk_label_new( _( params_ctx->params_list[i].desc ) );
+        gtk_widget_show( label );
+        gtk_box_pack_start( GTK_BOX( param_hbox ), label, FALSE, FALSE, 5 );
 
-   attackparams_v_ok_button = gtk_button_new_with_mnemonic (_("OK"));
-   gtk_widget_show (attackparams_v_ok_button);
-   gtk_box_pack_start (GTK_BOX (attackparams_vh_button), attackparams_v_ok_button, TRUE, FALSE, 0);
+        params_ctx->vh_entry[i] = gtk_entry_new();
 
-   /* TODO: attack_free_param */
-   g_signal_connect_swapped ((gpointer) attackparams_v_cancel_button, "clicked",
-         G_CALLBACK (gtk_widget_destroy),
-         GTK_OBJECT (attackparamsdialog));
+        gtk_entry_set_editable( GTK_ENTRY( params_ctx->vh_entry[i]), TRUE );
+        gtk_entry_set_width_chars( GTK_ENTRY( params_ctx->vh_entry[i] ), params_ctx->params_list[i].size_print );
+        gtk_entry_set_max_length( GTK_ENTRY( params_ctx->vh_entry[i] ), params_ctx->params_list[i].size_print );
 
-   g_signal_connect((gpointer) attackparams_v_ok_button, "clicked",
-         G_CALLBACK (gtk_c_attackparams_launch),
-         helper);
+        gtk_widget_show( params_ctx->vh_entry[i] );
+        gtk_box_pack_end( GTK_BOX( param_hbox ), params_ctx->vh_entry[i], FALSE, FALSE, 5 );
 
-   /* Store pointers to all widgets, for use by lookup_widget(). */
-   GLADE_HOOKUP_OBJECT_NO_REF (attackparamsdialog, attackparamsdialog, "attackparamsdialog");
-   GLADE_HOOKUP_OBJECT (attackparamsdialog, attackparams_vbox, "attackparams_vbox");
-   GLADE_HOOKUP_OBJECT (attackparamsdialog, attackparams_v_ok_button, "attackparams_v_ok_button");
-   GLADE_HOOKUP_OBJECT (attackparamsdialog, attackparams_v_cancel_button, "attackparams_v_cancel_button");
+        gtk_box_pack_start( GTK_BOX( frame_vbox ), param_hbox, FALSE, FALSE, 3 );
+        gtk_widget_show( param_hbox );
+    }
 
-   return attackparamsdialog;
+    button_hbox = gtk_hbox_new( FALSE, 0 );
+    gtk_box_pack_start( GTK_BOX( main_vbox ), button_hbox, FALSE, FALSE, 5 );
+
+    cancel_button = gtk_button_new_with_mnemonic( _( "Cancel" ) );
+    g_signal_connect( (gpointer) cancel_button, "clicked", G_CALLBACK( gtk_c_attackparams_cancel_click ), (gpointer)params_ctx );
+    gtk_box_pack_start( GTK_BOX( button_hbox ), cancel_button, TRUE, FALSE, 0 );
+
+    ok_button = gtk_button_new_with_mnemonic( _( "  OK  " ) );
+    g_signal_connect( (gpointer) ok_button, "clicked", G_CALLBACK( gtk_c_attackparams_ok_click ), (gpointer)params_ctx );
+    gtk_box_pack_start( GTK_BOX( button_hbox ), ok_button, TRUE, FALSE, 0 );
+
+    gtk_widget_show( cancel_button );
+    gtk_widget_show( ok_button );
+    gtk_widget_show( button_hbox );
+
+    gtk_widget_show( frame_vbox );
+    gtk_widget_show( frame );
+    gtk_widget_show( main_vbox );
+
+    g_signal_connect( main_dialog, "delete_event", G_CALLBACK( gtk_c_attackparams_delete_event ), (gpointer)params_ctx );
+
+    return main_dialog;
 }
 
 
@@ -1521,7 +1573,6 @@ create_protocol_mwindow(GtkWidget *Main, struct gtk_s_helper *helper, u_int8_t p
    GtkCellRenderer *cell;
    GtkTreeViewColumn *column;
    GType *types;
-   GtkTreeIter iter;
    PangoFontDescription *font_desc;
    char tmp_name[5], msg[1024];
 
@@ -1600,7 +1651,7 @@ create_protocol_mwindow(GtkWidget *Main, struct gtk_s_helper *helper, u_int8_t p
 
    /* Setup the click handler */
    g_signal_connect(protocols_tree[proto], "button-press-event", (GCallback) gtk_c_view_onButtonPressed, helper);
-   //	g_signal_connect(protocols_tree[proto], "popup-menu", (GCallback) gtk_c_view_onPopupMenu, NULL);
+   //    g_signal_connect(protocols_tree[proto], "popup-menu", (GCallback) gtk_c_view_onPopupMenu, NULL);
 
    /* Setup the selection handler */
 
@@ -1713,4 +1764,4 @@ gtk_i_view_menu(GtkWidget *treeview, GtkWidget *wmain, GdkEventButton *event, st
    GLADE_HOOKUP_OBJECT (wmain, menuitem, "menuitem");
 }
 
-/* vim:set tabstop=4:set expandtab:set shiftwidth=4:set textwidth=78: */
+/* vim:set tabstop=4:set expandtab:set shiftwidth=4:set textwidth=120: */
