@@ -1,11 +1,9 @@
 /* gtk_interface.h
  * Definitions for GTK Interfaces
  *
- * $Id: gtk-interface.h 43 2007-04-27 11:07:17Z slay $ 
- *
  * Yersinia
- * By David Barroso <tomac@yersinia.net> and Alfredo Andres <slay@yersinia.net>
- * Copyright 2005, 2006, 2007 Alfredo Andres and David Barroso
+ * By David Barroso <tomac@yersinia.net> and Alfredo Andres <aandreswork@hotmail.com>
+ * Copyright 2005-2017 Alfredo Andres and David Barroso
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -35,7 +33,7 @@ GtkWidget* gtk_i_create_Main (struct gtk_s_helper *);
 GtkWidget* gtk_i_create_opendialog (struct gtk_s_helper *);
 GtkWidget* gtk_i_create_savedialog (struct gtk_s_helper *);
 GtkWidget* gtk_i_create_capturedialog (struct gtk_s_helper *);
-GtkWidget* gtk_i_create_aboutdialog (void);
+void gtk_i_create_aboutdialog( GtkMenuItem *menuitem, gpointer user_data );
 GtkWidget* gtk_i_create_attacksdialog (GtkWidget *, struct gtk_s_helper *, u_int8_t);
 GtkWidget* create_viewpacketdialog (void);
 GtkWidget* create_interfacesdialog (struct term_node *);
@@ -44,9 +42,10 @@ GtkWidget* create_infodialog (void);
 GtkWidget* gtk_i_create_warningdialog (char *, ...);
 GtkWidget* gtk_i_create_extradialog (struct gtk_s_helper *);
 GtkWidget* gtk_i_create_add_extradialog (struct gtk_s_helper *, u_int8_t);
-GtkWidget* gtk_i_create_attackparamsdialog (struct gtk_s_helper *, struct attack_param *, u_int8_t);
+GtkWidget* gtk_i_create_attackparamsdialog( GTK_ATTACK_PARAMS_CONTEXT * );
 GtkWidget* create_protocol_mwindow(GtkWidget *, struct gtk_s_helper *, u_int8_t);
 void gtk_i_view_menu(GtkWidget *, GtkWidget *, GdkEventButton *, struct gtk_s_helper *);
+void gtk_i_modaldialog( int msg_type, char *header, char *msg, ...);
 
 /* For the credits comments */
 extern int8_t term_motd(void);
