@@ -1,11 +1,9 @@
 /* gtk_support.h
  * Definitions for GTK Support
  *
- * $Id: gtk-support.h 43 2007-04-27 11:07:17Z slay $ 
- *
  * Yersinia
- * By David Barroso <tomac@yersinia.net> and Alfredo Andres <slay@yersinia.net>
- * Copyright 2005, 2006, 2007 Alfredo Andres and David Barroso
+ * By David Barroso <tomac@yersinia.net> and Alfredo Andres <aandreswork@hotmail.com>
+ * Copyright 2005-2017 Alfredo Andres and David Barroso
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -92,17 +90,44 @@ void        glade_set_atk_action_description (AtkAction       *action,
 
 
 struct gtk_s_helper {
-	struct term_node *node;
-	u_int8_t mode;
-	u_int8_t row;
-	u_int8_t extra;
-	GtkWidget *notebook;
-	GtkTooltips *tooltips;
-   GtkTreeSelection *select;
-	GtkWidget *statusbar;
-	u_int8_t edit_mode;
-   struct attack *attack;
-   struct attack_param *attack_param;
+    struct term_node *node;
+    u_int8_t mode;
+    u_int8_t row;
+    u_int8_t extra;
+    GtkWidget *notebook;
+    GtkTooltips *tooltips;
+    GtkTreeSelection *select;
+    GtkWidget *statusbar;
+    u_int8_t edit_mode;
+    struct _attack_definition *attack_def;
+    struct attack_param *attack_param;
 };
 
+
+typedef struct _GTK_ATTACK_CONTEXT_ {
+    GtkWidget *dialog ;      /* Attacks list main dialog */
+    GtkWidget *h_box ;       /* Horizontal box where the current attack lies, useful for disabling graphically... */
+    struct term_node *node ;
+    u_int8_t protocol ;
+    u_int8_t attack ;
+} GTK_ATTACK_CONTEXT ;
+
+
+typedef struct _GTK_DIALOG_ATTACK_CONTEXT_ {
+    GtkWidget *dialog ;      /* Attacks list main dialog */
+    struct term_node *node ;
+    GTK_ATTACK_CONTEXT *enabled_attacks_list ;
+} GTK_DIALOG_ATTACK_CONTEXT ;
+
+
+typedef struct _GTK_ATTACK_PARAMS_CONTEXT_ {
+    struct gtk_s_helper *helper ;
+    GtkWidget *dialog ;           /* Attacks parameters dialog */
+    GtkWidget **vh_entry ;        /* Widget list relating to attack parameters */
+    u_int8_t nparams ;            /* parameters count */
+    struct attack_param *params_list ;
+    int8_t attack_status ;
+} GTK_ATTACK_PARAMS_CONTEXT ;
+
+
 #endif
