@@ -2,8 +2,8 @@
  * Implementation for ncurses GUI
  *
  * Yersinia
- * By David Barroso <tomac@yersinia.net> and Alfredo Andres <slay@yersinia.net>
- * Copyright 2005, 2006, 2007 Alfredo Andres and David Barroso
+ * By David Barroso <tomac@yersinia.net> and Alfredo Andres <aandreswork@hotmail.com>
+ * Copyright 2005-2017 Alfredo Andres and David Barroso
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,16 +20,13 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
-#ifndef lint
-static const char rcsid[] =
-"$Id: ncurses-gui.c 43 2007-04-27 11:07:17Z slay $";
-#endif
-
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
 
+#ifndef _REENTRANT
 #define _REENTRANT
+#endif
 
 #include <stdio.h>
 #include <errno.h>
@@ -129,7 +126,7 @@ ncurses_gui(void *args)
         ncurses_gui_th_exit(NULL);
     }
 
-    if (term_add_node(&term_node, TERM_CON, (int)NULL, pthread_self()) < 0)
+    if (term_add_node(&term_node, TERM_CON, 0, pthread_self()) < 0)
     {
        if (pthread_mutex_unlock(&terms->mutex) != 0)
           thread_error("ncurses_gui_th pthread_mutex_unlock",errno);
