@@ -2,8 +2,8 @@
  * Implementation for ncurses interfaces
  *
  * Yersinia
- * By David Barroso <tomac@yersinia.net> and Alfredo Andres <slay@yersinia.net>
- * Copyright 2005, 2006, 2007 Alfredo Andres and David Barroso
+ * By David Barroso <tomac@yersinia.net> and Alfredo Andres <aandreswork@hotmail.com>
+ * Copyright 2005-2017 Alfredo Andres and David Barroso
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,16 +20,13 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
-#ifndef lint
-static const char rcsid[] =
-"$Id: ncurses-interface.c 46 2007-05-08 09:13:30Z slay $";
-#endif
-
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
 
+#ifndef _REENTRANT
 #define _REENTRANT
+#endif
 
 #include <stdio.h>
 #include <errno.h>
@@ -368,15 +365,13 @@ ncurses_i_help_screen(u_int8_t mode, WINDOW *help_screen, PANEL *help_panel)
 /* 
  * Attack information panel
  */
-void 
-ncurses_i_attack_screen(struct term_node *node, u_int8_t mode, 
-        WINDOW *attack_screen, PANEL *attack_panel)
+void ncurses_i_attack_screen( struct term_node *node, u_int8_t mode, WINDOW *attack_screen, PANEL *attack_panel )
 {
    int32_t i, key_pressed=0, j, row, col, y, x;
    u_int8_t field;
    int8_t ret;
    struct attack_param *attack_param = NULL;
-   struct attack *theattack = NULL;
+   struct _attack_definition *attack_def = NULL;
 
    ncurses_c_set_status_line(" Those strange attacks... ");
 
@@ -386,9 +381,10 @@ ncurses_i_attack_screen(struct term_node *node, u_int8_t mode,
    if ((row - 15 != y) || (col - 50 != x))
       mvwin(attack_screen, (row - 15)/2, (col - 50)/2);
 
-   if (protocols[mode].attacks)
-      theattack = protocols[mode].attacks;
-   else {
+   if ( protocols[ mode ].attack_def_list )
+      attack_def = protocols[ mode ].attack_def_list;
+   else 
+   {
       write_log(0, "Warning: no attacks for mode %d\n", mode);
       return;
    }
@@ -402,11 +398,11 @@ ncurses_i_attack_screen(struct term_node *node, u_int8_t mode,
    mvwprintw(attack_screen, 1, 2, "No   DoS   Description");
    wattroff(attack_screen, COLOR_PAIR(1));
 
-   while(theattack[i].s != NULL) 
+   while( attack_def[i].desc != NULL ) 
    {
       mvwprintw(attack_screen, i+2, 2, "%d", i);
-      mvwprintw(attack_screen, i+2, 7, "%c", (theattack[i].type == DOS) ? 'X' : ' ');
-      mvwprintw(attack_screen, i+2, 13, "%s", theattack[i].s);
+      mvwprintw(attack_screen, i+2, 7, "%c", (attack_def[i].type == DOS) ? 'X' : ' ');
+      mvwprintw(attack_screen, i+2, 13, "%s", attack_def[i].desc);
       i++;
    }
 
@@ -434,18 +430,18 @@ ncurses_i_attack_screen(struct term_node *node, u_int8_t mode,
             if (j < i) 
             { /* does the attack exist? */
 
-               if (theattack[j].nparams) /* Do we need parameters for attack? */
+               if ( attack_def[j].nparams) /* Do we need parameters for attack? */
                {
                   if ((attack_param = calloc(1,
-                              (sizeof(struct attack_param) * theattack[j].nparams))) == NULL)
+                              (sizeof(struct attack_param) * attack_def[j].nparams))) == NULL)
                   {
                      thread_error(" ncurses_i_attack_screen attack_param calloc",errno);
                      key_pressed='Q';
                      break;
                   }
-                  memcpy( attack_param, (void *)(theattack[j].param),
-                        sizeof(struct attack_param) * theattack[j].nparams);
-                  if (attack_init_params(node, attack_param, theattack[j].nparams) < 0)
+                  memcpy( attack_param, (void *)( attack_def[j].param),
+                        sizeof(struct attack_param) * attack_def[j].nparams);
+                  if (attack_init_params(node, attack_param, attack_def[j].nparams) < 0)
                   {
                      free(attack_param);
                      key_pressed='Q';
@@ -456,23 +452,23 @@ ncurses_i_attack_screen(struct term_node *node, u_int8_t mode,
                   hide_panel(attack_panel);
 
                   /* Now we can ask for parameters... */
-                  ncurses_i_get_printable_store(attack_param, theattack[j].nparams);
+                  ncurses_i_get_printable_store(attack_param, attack_def[j].nparams);
 
                   do {
-                     if (ncurses_i_attack_get_params(attack_param, 
-                              theattack[j].nparams) < 0) /* Q pressed */
+                     if (ncurses_i_attack_get_params(attack_param, attack_def[j].nparams) < 0) /* Q pressed */
                      {
-                        attack_free_params(attack_param, theattack[j].nparams);
+                        attack_free_params(attack_param, attack_def[j].nparams);
                         free(attack_param);
                         key_pressed='Q';
                         break;
                      }
-                     ret = attack_filter_all_params(attack_param,theattack[j].nparams, &field);
+                     ret = attack_filter_all_params( attack_param, attack_def[j].nparams, &field );
                      if ( ret == -1) /* Error on data...*/
                      {
-                        ncurses_i_error_window(1,
-                              "Bad data on field '%s'!!",
-                              attack_param[field].desc);
+                        if ( attack_param[field].type == FIELD_ENABLED_IFACE )
+                            ncurses_i_error_window( 1, "Nonexistant or disabled network interface on field '%s'!!", attack_param[field].desc );
+                        else
+                            ncurses_i_error_window( 1, "Bad data on field '%s'!!", attack_param[field].desc );
                      }
                   } while(ret==-1);
 
@@ -487,11 +483,11 @@ ncurses_i_attack_screen(struct term_node *node, u_int8_t mode,
                      mvwprintw(attack_screen, 1, 2, "No   DoS   Description");
                      wattroff(attack_screen, COLOR_PAIR(1));
 
-                     while(theattack[i].s != NULL) 
+                     while ( attack_def[i].desc != NULL )
                      {
                         mvwprintw(attack_screen, i+2, 2, "%d", i);
-                        mvwprintw(attack_screen, i+2, 7, "%c", (theattack[i].type == DOS) ? 'X' : ' ');
-                        mvwprintw(attack_screen, i+2, 13, "%s", theattack[i].s);
+                        mvwprintw(attack_screen, i+2, 7, "%c", ( attack_def[i].type == DOS) ? 'X' : ' ');
+                        mvwprintw(attack_screen, i+2, 13, "%s", attack_def[i].desc);
                         i++;
                      }
 
@@ -504,7 +500,7 @@ ncurses_i_attack_screen(struct term_node *node, u_int8_t mode,
                show_panel(attack_panel);
                ncurses_c_refresh();
 
-               if (attack_launch(node, mode, j, attack_param, theattack[j].nparams) < 0)
+               if (attack_launch(node, mode, j, attack_param, attack_def[j].nparams) < 0)
                   write_log(0, "Error launching attack %d", j);
 
                key_pressed='Q';
@@ -625,22 +621,18 @@ ncurses_i_ifaces_screen(struct term_node *node, WINDOW *ifaces_window,
 int8_t
 ncurses_i_show_info(u_int8_t mode, WINDOW *main_window, u_int8_t pointer, struct term_node *node)
 {
-   u_int8_t i, j, line, row, col, k;
+   u_int8_t j, line, row, col, k;
    int32_t key_pressed;
    WINDOW *info_window;
    char **values, *ptrtlv;
-   struct tuple_type_desc *func;
    struct commands_param *params;
 
-   func = NULL;
-
    ncurses_c_set_status_line(" Information should be free ");
 
    getmaxyx(main_window,row,col);
    info_window = newpad(MAX_PAD_HEIGHT, MAX_PAD_WIDTH);
    keypad(info_window, TRUE);
 
-   i = 0;
    line = 0;
    params = (struct commands_param *) protocols[mode].parameters;
 
@@ -873,12 +865,11 @@ ncurses_i_view_packet(u_int8_t mode, WINDOW *main_window, u_int8_t pointer)
 /* 
  * List attack
  */
-void 
-ncurses_i_list_attacks(WINDOW *list_window, struct term_node *node)
+void ncurses_i_list_attacks( WINDOW *list_window, struct term_node *node )
 {
    u_int8_t end, kill, j, pointer, a, i, used, indx=0, files[MAX_PROTOCOLS*MAX_THREAD_ATTACK][2];
    int32_t key_pressed;
-   struct attack *theattack = NULL;
+   struct _attack_definition *attack_def = NULL;
 
    used = 0; j = 0;
 
@@ -940,12 +931,12 @@ ncurses_i_list_attacks(WINDOW *list_window, struct term_node *node)
 
          if (node->protocol[files[i][0]].attacks[files[i][1]].up) 
          {
-            theattack = protocols[files[i][0]].attacks;
+            attack_def = protocols[files[i][0]].attack_def_list;
 
             mvwprintw(list_window, i+4, 2, "%8s   %-2d      %s", 
                   protocols[files[i][0]].namep, 
                   node->protocol[files[i][0]].attacks[files[i][1]].attack, 
-                  theattack[node->protocol[files[i][0]].attacks[files[i][1]].attack].s);
+                  attack_def[ node->protocol[files[i][0]].attacks[files[i][1]].attack].desc);
          }
          i++;
       }
@@ -1539,14 +1530,12 @@ ncurses_i_add_selected_tlv_type(WINDOW *win, struct term_node *node, u_int8_t mo
    int32_t i, pointer, end, key_pressed;
    struct attack_param *attack_param;
    struct commands_param_extra_item *newitem;
-   u_int32_t type;
    u_int8_t field;
    int8_t ret;
    void *extra;
 
    pointer = 0;
    end = 0;
-   type = 0;
    i = 0;
    key_pressed = 0;
    attack_param = NULL;
@@ -1773,7 +1762,7 @@ ncurses_i_attack_get_params(struct attack_param *param, u_int8_t nparams)
    u_int8_t i, end_edit=0, offset_x=0, offset_y, origin_x, origin_y, max_print=0;
    int8_t ret=0;
    int32_t key_pressed;
-   char *bottom = "ESC/Q to abort - ENTER to continue";
+   char *bottom = "ESC to abort - ENTER to continue";
    WINDOW *my_window;
    PANEL *my_panel;
 
@@ -1937,8 +1926,9 @@ ncurses_i_attack_get_params(struct attack_param *param, u_int8_t nparams)
             getyx(my_window, y, x);
 
             if ((key_pressed == 'Q' || key_pressed == 'q') && 
-                  (param[y-offset_y].type != FIELD_STR) &&
-                  (param[y-offset_y].type != FIELD_IFACE) )
+                  ( param[y-offset_y].type != FIELD_STR ) &&
+                  ( param[y-offset_y].type != FIELD_IFACE ) &&
+                  ( param[y-offset_y].type != FIELD_ENABLED_IFACE ) )
             {
                end_edit = 1;
                ret = -1;
@@ -1952,20 +1942,21 @@ ncurses_i_attack_get_params(struct attack_param *param, u_int8_t nparams)
                   /* only hexadecimal characters are allowed */
                   break;
             } 
-            else 
-               if ((param[y-offset_y].type == FIELD_DEC) || 
-                     (param[y-offset_y].type == FIELD_IP)) 
+            else
+               if ((param[y-offset_y].type == FIELD_DEC) ||
+                     (param[y-offset_y].type == FIELD_IP))
                {
                   if (!isdigit(key_pressed))
                      break;
-               } 
-               else 
-                  if ( (param[y-offset_y].type == FIELD_STR) ||
-                        (param[y-offset_y].type == FIELD_IFACE) ) 
+               }
+               else
+                  if ( ( param[y-offset_y].type == FIELD_STR ) ||
+                       ( param[y-offset_y].type == FIELD_IFACE ) ||
+                       ( param[y-offset_y].type == FIELD_ENABLED_IFACE ) )
                   {
                      if (!isascii(key_pressed))
                         break;
-                  } 
+                  }
                   else /* FIELD_NONE */
                      break;
 
