@@ -2,8 +2,8 @@
  * Main command line parser and parser utilities
  *
  * Yersinia
- * By David Barroso <tomac@yersinia.net> and Alfredo Andres <slay@yersinia.net>
- * Copyright 2005, 2006, 2007 Alfredo Andres and David Barroso
+ * By David Barroso <tomac@yersinia.net> and Alfredo Andres <aandreswork@hotmail.com>
+ * Copyright 2005-2017 Alfredo Andres and David Barroso
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,16 +20,13 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
-#ifndef lint
-static const char rcsid[] = 
-"$Id: parser.c 46 2007-05-08 09:13:30Z slay $";
-#endif
-
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
 
+#ifndef _REENTRANT
 #define _REENTRANT
+#endif
 
 #include <stdio.h>
 #include <errno.h>
@@ -254,11 +251,11 @@ parser_vrfy_mac( char *address, u_int8_t *destination )
     u_int16_t i=0, j;
 
     substr = address;
-	/* trim left spaces (can exist in the configuration file) */
-/*	while (*substr == ' ')
-		substr++;*/
+    /* trim left spaces (can exist in the configuration file) */
+/*    while (*substr == ' ')
+        substr++;*/
 
-	aux = substr;
+    aux = substr;
 
     while ( (substr = strchr(substr, ':') ))
     {
@@ -340,7 +337,7 @@ parser_vrfy_bridge_id( char *address, u_int8_t *destination )
     if (*aux != '.')
         return -1;
 
-	aux++;
+    aux++;
 
     for (i=0; i<6; i++)
     {
@@ -406,15 +403,15 @@ parser_help(void)
  *
  */
 int8_t
-parser_command2index(register const struct attack *lp, register int8_t v)
+parser_command2index(register const struct _attack_definition *attack_def, register int8_t v)
 {
     int i=0;
 
-    while (lp->s != NULL) 
+    while ( attack_def->desc != NULL ) 
     {
-        if (lp->v == v)
+        if ( attack_def->v == v )
             return (i);
-        ++lp;
+        ++attack_def;
         ++i;
     }
     return (i);
@@ -547,10 +544,10 @@ parser_get_random_string(u_int8_t *string, u_int8_t len)
         return -1;
 
     while (total < len-1) {
-	if (gettimeofday(&tv, NULL) < 0) {
-		thread_error("Error in gettimeofday", errno);
-		return -1;
-	}
+    if (gettimeofday(&tv, NULL) < 0) {
+        thread_error("Error in gettimeofday", errno);
+        return -1;
+    }
 
 #ifdef HAVE_RAND_R
        i = (u_int32_t)tv.tv_usec;
@@ -624,13 +621,12 @@ parser_read_config_file(struct term_tty *tty, struct term_node *node)
    FILE *file;
    char buffer[BUFSIZ], *ptr, *ptr2;
    u_int8_t state, i;
-   int16_t proto, field;
+   int16_t proto;
    struct commands_param *params;
 
    params = NULL;
    state = 0;
    proto = -1;
-   field = -1;
 
    if ((file = fopen(tty->config_file, "r")) == NULL) {
       write_log(1, "Error opening configuration file %s\n", tty->config_file);
@@ -918,7 +914,6 @@ parser_write_config_file(struct term_tty *tty)
       return -1;
    }
 
-   fputs("# $Id: parser.c 46 2007-05-08 09:13:30Z slay $\n", file);
    fputs("#\n", file);
    fputs("# Yersinia configuration file example\n", file);
    fputs("#\n", file);
@@ -1374,12 +1369,11 @@ parser_filter_param(u_int8_t type, void *value, char *printable,
    u_int8_t i, *bytes, j;
    char tmp[3];
    char *temp;
-//   int8_t iface;
+   int16_t iface;
    u_int16_t end, len, len2;
    u_int32_t aux_ip;
    struct in_addr addr;
 
-//write_log(0, "tipe es %d, value %s, printable %s, size %d\n", type, value, printable, size_print);
    if (type == FIELD_TLV)
       return 0;
 
@@ -1470,17 +1464,34 @@ parser_filter_param(u_int8_t type, void *value, char *printable,
          break;
 
       case FIELD_IFACE:
+         end = strlen( printable );
+         for( i=0 ; i < end ; i++ )
+         {
+            if ( ! isascii( printable[i] ) )
+               return -1;
+         }
+         iface = interfaces_get( printable );
+
+         if ( iface < 0 )
+            return -1;
+
+         memset((void *)value, 0, strlen(value));
+         memcpy((void *)value, (void *)printable, end);
+         break;
+
+      case FIELD_ENABLED_IFACE:
          end = strlen(printable);
          for(i=0; i<end; i++)
          {
             if ( !isascii(printable[i]) )
                return -1;
          }
-/*         iface = interfaces_get(printable);
-         if (iface < 0)
+
+         iface = interfaces_get_enabled( printable );
+
+         if ( iface < 0 )
             return -1;
-         memcpy((void *)value, (void *)&iface, 1);
-*/
+
          memset((void *)value, 0, strlen(value));
          memcpy((void *)value, (void *)printable, end);
          break;
@@ -1546,9 +1557,8 @@ parser_cl_proto( struct term_node *node, int8_t argc, char **args, u_int8_t prot
 {
     int8_t aux, tmp, ifaces, i, j, has_help, has_arg, fail, gotit;
     char *param;
-    u_int32_t aux_long;
     struct term_tty *term_tty=NULL;
-    struct attack *first_attack;
+    struct _attack_definition *first_attack;
     struct commands_param *comm_par;
     dlist_t *p = NULL;
     struct interface_data *iface_data;
@@ -1646,28 +1656,28 @@ parser_cl_proto( struct term_node *node, int8_t argc, char **args, u_int8_t prot
              write_log(2,"Parameter 'attack' needs an argument!!\n");
              return -1;
           }
-          if (!protocols[proto].attacks)
+          if (!protocols[proto].attack_def_list)
           {
              write_log(2,"Ouch!! No attacks defined for protocol %s!!\n",protocols[proto].namep);
              return -1;
           }
           if (has_help)
           {
-              first_attack =  protocols[proto].attacks;
-              while (first_attack->s != NULL) 
+              first_attack =  protocols[proto].attack_def_list;
+              while (first_attack->desc != NULL) 
               {
                   write_log(2,"    <%d>    %s attack %s\n",first_attack->v,
                             (first_attack->type)?"DOS":"NONDOS", 
-                            first_attack->s);
+                            first_attack->desc);
                   ++first_attack;
               }
               return -1;
           }
           aux_args++;
           aux = atoi(*aux_args);
-          first_attack =  protocols[proto].attacks;          
+          first_attack = protocols[proto].attack_def_list;          
           j=0;
-          while(first_attack[j].s != NULL)
+          while(first_attack[j].desc != NULL)
                 j++;
           if ( (aux < 0) || (aux > (j-1)) )
           {
@@ -1714,14 +1724,6 @@ parser_cl_proto( struct term_node *node, int8_t argc, char **args, u_int8_t prot
                      return -1;
                   }
 
-                  if (comm_par[j].type == FIELD_IP)
-                  {
-                     memcpy((void *)&aux_long, (void *)node->protocol[proto].commands_param[j], 4);
-                     aux_long = ntohl(aux_long);
-                     memcpy((void *)node->protocol[proto].commands_param[j], (void *)&aux_long, 4);
-                  }
-
-                 
                  if (comm_par[j].filter) /* Use specific filter for this param */
                  {
 
@@ -1920,4 +1922,4 @@ parser_get_max_field_length(const struct tuple_type_desc *tuple)
    return max;
 }
 
-/* vim:set tabstop=3:set expandtab:set shiftwidth=3:set textwidth=78: */
+/* vim:set tabstop=3:set expandtab:set shiftwidth=3:set textwidth=120: */
