@@ -2,8 +2,8 @@
  * Command line client and application main entry point
  *
  * Yersinia
- * By David Barroso <tomac@yersinia.net> and Alfredo Andres <slay@yersinia.net>
- * Copyright 2005, 2006, 2007 Alfredo Andres and David Barroso
+ * By David Barroso <tomac@yersinia.net> and Alfredo Andres <aandreswork@hotmail.com>
+ * Copyright 2005-2017 Alfredo Andres and David Barroso
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,16 +20,13 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
-#ifndef lint
-static const char rcsid[] = 
-"$Id: yersinia.c 43 2007-04-27 11:07:17Z slay $";
-#endif
-
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
 
+#ifndef _REENTRANT
 #define _REENTRANT
+#endif
 
 #include <stdio.h>
 #include <errno.h>
@@ -328,7 +325,7 @@ write_log(0, "\n th_tty_peer thread = %d...\n",(int)pthread_self());
       th_tty_peer_exit(NULL);
    }
    
-   fail = term_add_node(&term_node, TERM_TTY, (int)NULL, pthread_self());
+   fail = term_add_node(&term_node, TERM_TTY, 0, pthread_self());
 
    if (fail == -1)
    {
@@ -460,33 +457,29 @@ void
 doloop(struct term_node *node, int mode)
 {
     struct term_tty *term_tty;
-    struct attack *theattack = NULL;
+    struct _attack_definition *attack_def = NULL;
     struct timeval timeout;
     fd_set read_set;
     int ret, fail;
     struct termios old_term, term;
-    
+
     term_tty = node->specific;
 
-    theattack = protocols[mode].attacks;
+    attack_def = protocols[ mode ].attack_def_list ;
 
-    if (term_tty->attack >= 0) 
+    if ( term_tty->attack >= 0 )
     {
-        if (theattack[term_tty->attack].nparams)
+        if ( attack_def[ term_tty->attack ].nparams )
         {
             printf("\n<*> Ouch!! At the moment the command line interface doesn't support attacks <*>\n");
-            printf("<*> that needs parameters and the one you've choosed needs %d <*>\n",
-                         theattack[term_tty->attack].nparams);
+            printf("<*> that needs parameters and the one you've choosed needs %d <*>\n", attack_def[ term_tty->attack ].nparams );
         }
         else
         {
-            printf("<*> Starting %s attack %s...\n", 
-                (theattack[term_tty->attack].type)?"DOS":"NONDOS",
-                theattack[term_tty->attack].s); 
+            printf("<*> Starting %s attack %s...\n", ( attack_def[ term_tty->attack ].type ) ? "DOS" : "NONDOS", attack_def[ term_tty->attack ].desc);
 
             if (attack_launch(node, mode, term_tty->attack, NULL, 0) < 0)
-                write_log(1, "Error launching attack %d (mode %d)!!\n", 
-                            term_tty->attack, mode);
+                write_log(1, "Error launching attack %d (mode %d)!!\n", term_tty->attack, mode);
 
             fflush(stdin); fflush(stdout);
             setvbuf(stdout, NULL, _IONBF, 0);
@@ -498,10 +491,11 @@ doloop(struct term_node *node, int mode)
             term.c_lflag &= ~ECHO;
             tcsetattr(0,TCSANOW,&term);
 
-            if (theattack[term_tty->attack].single == CONTINOUS) {
+            if ( attack_def[ term_tty->attack ].single == CONTINOUS ) 
+            {
                 printf("<*> Press any key to stop the attack <*>\n");
                 fail = 0;
-                while(!fail && !node->thread.stop)
+                while( !fail && !node->thread.stop )
                 {
                     FD_ZERO(&read_set);
                     FD_SET(0, &read_set);
@@ -524,7 +518,8 @@ doloop(struct term_node *node, int mode)
                        }
                     }
                  }
-             } else
+            } 
+            else
                 /* Command line, only one attack (0), let's wait for its conclusion... */
                 while (node->protocol[mode].attacks[0].up)
                     thread_usleep(150000);
@@ -545,7 +540,7 @@ th_uptime(void *arg)
    struct timeval timeout;
    sigset_t mask;
 
-write_log(0,"\n th_uptime thread = %d\n",(int)pthread_self());
+write_log(0,"\n th_uptime thread = %X\n",(int)pthread_self());
 
    sigfillset(&mask);
 
@@ -653,10 +648,6 @@ void
 write_log( u_int16_t mode, char *msg, ... )
 {
     va_list ap; /* Variable argument list...*/
-#ifdef HAVE_GTK
-	char buffer[4096];
-	GtkTextIter iter2;
-#endif
 
     va_start(ap,msg);
 
@@ -666,16 +657,30 @@ write_log( u_int16_t mode, char *msg, ... )
     if ((!mode || (mode == 1)) && (tty_tmp->log_file))
        vfprintf(tty_tmp->log_file, msg,ap);
 
-	/* Send yersinia log to the main_log gtk widget */
+    va_end(ap);
+
 #ifdef HAVE_GTK
-    if ((!mode || (mode == 1)) && ((tty_tmp->gtk) && (tty_tmp->buffer_log))) {
-       vsnprintf(buffer, 4096, msg,ap);
-	   gtk_text_buffer_get_iter_at_offset (GTK_TEXT_BUFFER (tty_tmp->buffer_log), &iter2, 0);
-	   gtk_text_buffer_insert(GTK_TEXT_BUFFER(tty_tmp->buffer_log), &iter2, buffer, -1);
-	}
+    /* Send yersinia log to the main_log gtk widget */
+    if ((!mode || (mode == 1)) && ((tty_tmp->gtk) && (tty_tmp->buffer_log))) 
+    {
+        GtkTextIter iter2;
+        char *buffer = (char *)malloc( 2048 );
+
+        if ( buffer )
+        {
+            va_start( ap,msg );
+
+            vsnprintf( buffer, 2048, msg, ap );
+            gtk_text_buffer_get_iter_at_offset( GTK_TEXT_BUFFER (tty_tmp->buffer_log), &iter2, 0 );
+            gtk_text_buffer_insert( GTK_TEXT_BUFFER(tty_tmp->buffer_log), &iter2, buffer, -1 );
+
+            va_end(ap);
+
+            free( buffer );
+        }
+    }
 #endif
 
-    va_end(ap);
 }
 
 
@@ -754,7 +759,7 @@ clean_exit(void)
 void 
 g00dbye(void)
 {
-    write_log(0," g00dbye function called from %d\n",(int)pthread_self());
+    write_log(0," g00dbye function called from %X\n",(int)pthread_self());
     
     term_delete_all_tty();
     
@@ -861,7 +866,7 @@ init_attribs(struct term_node *node)
         if (!protocols[i].visible)
            continue;
         if (protocols[i].init_attribs)
-	   result = result | (*protocols[i].init_attribs)(node);
+       result = result | (*protocols[i].init_attribs)(node);
         else
            write_log(0, "Warning: protocol %d has no init_attribs function!!\n", i);
     }
